<?php 

namespace Teknisa\MAN\Services;

use Teknisa\MAN\Utilities;
use \Doctrine\ORM\EntityManager;


class ProdutividadeVendedor {
    
	protected $entityManager; 

	public function __construct(EntityManager $entityManager)  {
		$this->entityManager = $entityManager;
	}

    private function setReportParameters(&$params, &$conditions) {
        $params = array(
            ':CDLOJA' => isset($conditions['CDLOJA']) ? $conditions['CDLOJA'] : null ,
            ':TCDLOJA' => isset($conditions['TCDLOJA']) ? $conditions['TCDLOJA'] : null ,
            ':DATAINI' => isset($conditions['DATAINI']) ? $conditions['DATAINI'] : null ,
            ':DATAFIN' => isset($conditions['DATAFIN']) ? $conditions['DATAFIN'] : null ,
            ':CDFILIAL' => isset($conditions['CDFILIAL']) ? $conditions['CDFILIAL'] : null ,
            ':CDPRODUTO' => isset($conditions['CDPRODUTO']) ? $conditions['CDPRODUTO'] : null ,
            ':TCDFILIAL' => isset($conditions['TCDFILIAL']) ? $conditions['TCDFILIAL'] : null ,
            ':CDVENDEDOR' => isset($conditions['CDVENDEDOR']) ? $conditions['CDVENDEDOR'] : null ,
            ':TCDPRODUTO' => isset($conditions['TCDPRODUTO']) ? $conditions['TCDPRODUTO'] : null ,
            ':TCDVENDEDOR' => isset($conditions['TCDVENDEDOR']) ? $conditions['TCDVENDEDOR'] : null ,
            ':CDPRODUTOAVO' => isset($conditions['CDPRODUTOAVO']) ? $conditions['CDPRODUTOAVO'] : null ,
            ':DTMOVTURCAIX' => isset($conditions['DTMOVTURCAIX']) ? $conditions['DTMOVTURCAIX'] : null ,
            ':TDTMOVTURCAIX' => isset($conditions['TDTMOVTURCAIX']) ? $conditions['TDTMOVTURCAIX'] : null ,
            ':TCDPRODUTOAVO' => isset($conditions['TCDPRODUTOAVO']) ? $conditions['TCDPRODUTOAVO'] : null ,
            ':NRORG' => $conditions['NRORG']
        );
    } 
    
    public function getProdutividadeVendedor($conditions) {
    	$params = [];
        $this->setReportParameters($params, $conditions);
        
        // colunas VRLIQUIDO e VRFINALITEM so mudam a questao do Repique um soma e outro nao
        // a coluna VRPRODVENDA ja tem calculo do acrescimo, por isso nao pode esta na coluna de VRLIQUIDO como soma
        if($conditions['TIPORELATORIO'] == 'A'){
            return $this->entityManager->getConnection()->fetchAll(self::REL_PRODUTIVIDADE_VENDEDOR_ANALITICO, $params);
        }
        elseif ($conditions['TIPORELATORIO'] == 'S') {
            return $this->entityManager->getConnection()->fetchAll(self::REL_PRODUTIVIDADE_VENDEDOR_SINTETICO, $params);
        }
    }
    
    

    const REL_PRODUTIVIDADE_VENDEDOR_ANALITICO = "
         SELECT TOTAL.*,PP.CDARVPROD AS CDARVPRODPAI,PPP.CDARVPROD AS CDARVPRODAVO ,PP.NMPRODUTO AS NMPRODUTOPAI ,PPP.NMPRODUTO AS NMPRODUTOAVO FROM( 
    SELECT
        ( CDFILIAL
          || ' - '
          || NMFILIAL )
        || ' - '
        || ( CDLOJA
             || ' - '
             || NMLOJA ) AS LABELFILIAL,
        ( CDVENDEDOR
          || ' - '
          || NMRAZSOCVEN ) AS GARCON,
        FINAL.*,
        SUM(VRREPITEM) OVER(
            PARTITION BY CDFILIAL, CDLOJA, CDVENDEDOR
        ) VRTOTREP,
        FINAL.VRPRODVENDA + FINAL.VRREPITEM + FINAL.VRGORJETA + FINAL.VRTXENTREGA VRFINALITEM,
        (FINAL.VRPRODVENDA + FINAL.VRGORJETA + FINAL.VRTXENTREGA) VRLIQUIDO
    FROM
        (
            SELECT
                CONSOLIDADO.CDFILIAL,
                CONSOLIDADO.NMFILIAL,
                CONSOLIDADO.CDLOJA,
                CONSOLIDADO.NMLOJA,
                CONSOLIDADO.CDARVPROD,
                CONSOLIDADO.NMPRODUTO,
                CONSOLIDADO.CDVENDEDOR,
                CONSOLIDADO.NMRAZSOCVEN,
                CONSOLIDADO.VRUNIT,
                NVL(SUM(((VRGORJETAVENDA - VRREPIQUEVENDA) * DECODE(IDCOBTXSERV, 'S', VRPRODVENDA, 0)) / VRGERALITEMVENDA), 0) VRGORJETA,
                NVL(SUM(((VRTXENTREGAVENDA - VRREPIQUEVENDA) * DECODE(IDCOBTXSERV, 'S', VRPRODVENDA, 0)) / VRGERALITEMVENDA), 0) VRTXENTREGA,
                SUM(QTPRODVEND) QTPRODVEND,
                SUM(ACR) ACR,
                SUM(DES) DES,
                SUM(VRPRODVENDA) VRPRODVENDA,
                SUM(VRREPITEMTEMP / VRGERALITEMVENDA) AS VRREPITEM,
                NVL(SUM(VRREPIQUEVENDA), 0) AS VRREPIQUEVENDA,               
                CONSOLIDADO.CDPRODUTO,
                CONSOLIDADO.CDPRODNIVANTE
            FROM
                (
                    SELECT
                        RELATORIO.CDFILIAL,
                        RELATORIO.NMFILIAL,
                        RELATORIO.CDLOJA,
                        RELATORIO.NMLOJA,
                        RELATORIO.CDARVPROD,
                        RELATORIO.NMPRODUTO,
                        RELATORIO.CDVENDEDOR,
                        RELATORIO.NMRAZSOCVEN,
                        RELATORIO.VRUNIT,
                        RELATORIO.NRSEQVENDA,
                        RELATORIO.IDCOBTXSERV,
                        NVL(RELATORIO.VRREPIQUEVENDA, 0) VRREPIQUEVENDA,
                        SUM(RELATORIO.QTPRODVEND) QTPRODVEND,
                        SUM(RELATORIO.ACR) ACR,
                        SUM(RELATORIO.DES) DES,
                        SUM(RELATORIO.VRPRODVENDA) VRPRODVENDA,
                        SUM(RELATORIO.VRGORJETA) VRGORJETAVENDA,
                        SUM(RELATORIO.VRTXENTREGA) VRTXENTREGAVENDA,
                        NVL(SUM(RELATORIO.VRREPIQUEVENDA * RELATORIO.VRPRODVENDA), 0) VRREPITEMTEMP,
                        SUM(RELATORIO.VRITENS) VRGERALITEMVENDA,                        
                        RELATORIO.CDPRODUTO,
                        RELATORIO.CDPRODNIVANTE
                        
                    FROM
                        (
                            SELECT DISTINCT
                                DADOSITEM.CDFILIAL,
                                DADOSITEM.NMFILIAL,
                                DADOSITEM.CDLOJA,
                                DADOSITEM.NMLOJA,
                                DADOSITEM.CDARVPROD,
                                DADOSITEM.NMPRODUTO,
                                DADOSITEM.CDVENDEDOR,
                                DADOSITEM.NMRAZSOCVEN,
                                DADOSITEM.QTPRODVEND,
                                DADOSITEM.ACR,
                                DADOSITEM.DES,
                                DADOSITEM.VRPRODVENDA,
                                DADOSITEM.VRUNIT,
                                DADOSITEM.VRREPIQUEVENDA,
                                DADOSITEM.NRSEQVENDA,
                                VRITENS,
                                VRGORJETA,
                                VRTXENTREGA,
                                DADOSITEM.IDCOBTXSERV,                                
                                DADOSITEM.CDPRODUTO,
                                DADOSITEM.CDPRODNIVANTE
                            FROM
                                (
                                    SELECT DISTINCT
                                        FILTROREL.CDFILIAL,
                                        FILTROREL.NMFILIAL,
                                        FILTROREL.CDLOJA,
                                        FILTROREL.NMLOJA,
                                        FILTROREL.CDPRODUTO,
                                        P.CDARVPROD,
                                        P.NMPRODUTO,
                                        FILTROREL.CDVENDEDOR,
                                        FILTROREL.CDPRODTAXASERV,
                                        FILTROREL.CDPRODTAXAENTR,
                                        FILTROREL.NMRAZSOCVEN,
                                        FILTROREL.CDCAIXA,
                                        FILTROREL.VRREPIQUEVENDA,
                                        FILTROREL.QTPRODVEND,
                                        FILTROREL.ACR,
                                        FILTROREL.DES,
                                        FILTROREL.VRPRODVENDA,
                                        FILTROREL.NRSEQVENDA,
                                        FILTROREL.VRUNIT,
                                        FILTROREL.IDCOBTXSERV,                                        
                                        P.CDPRODNIVANTE
                                    FROM
                                        (
                                            SELECT DISTINCT
                                                FILTROVENDA.CDFILIAL,
                                                FILTROVENDA.NMFILIAL,
                                                FILTROVENDA.CDLOJA,
                                                FILTROVENDA.NMLOJA,
                                                I.CDPRODUTO,
                                                NVL(I.CDVENDEDOR, FILTROVENDA.CDVENDEDOR) CDVENDEDOR,
                                                FILTROVENDA.NRSEQVENDA,
                                                FILTROVENDA.CDPRODTAXASERV,
                                                FILTROVENDA.CDPRODTAXAENTR,
                                                FILTROVENDA.CDCAIXA,
                                                V.NMRAZSOCVEN,
                                                FILTROVENDA.VRREPIQUEVENDA,
                                                TRUNC(I.VRUNITVEND, 2) AS VRUNIT,
                                                P.IDCOBTXSERV,
                                                SUM(I.QTPRODVEND) QTPRODVEND,
                                                SUM(I.VRACRITVEND) ACR,
                                                SUM(I.VRDESITVEND) DES,
                                                SUM(TRUNC(I.QTPRODVEND *(I.VRUNITVEND + NVL(I.VRUNITVENDCL, 0)), 2) - NVL(I.VRDESITVEND
                                                , 0) + NVL(I.VRACRITVEND, 0)) AS VRPRODVENDA                                                
                                                
                                            FROM
                                                (
                                                    SELECT
                                                        CDVENDEDOR,
                                                        NMRAZSOCVEN
                                                    FROM
                                                        VENDEDOR
                                                    WHERE
                                                        ( ( INSTR(:CDVENDEDOR, CDVENDEDOR) > 0 )
                                                          OR ( :TCDVENDEDOR = 'T' ) )
                                                ) V,
                                                (
                                                    SELECT DISTINCT
                                                        VE.CDFILIAL,
                                                        VE.CDCAIXA,
                                                        VE.CDLOJA,
                                                        VE.NRSEQVENDA,
                                                        FILTROGER.CDFILIAL
                                                        || VE.CDCAIXA
                                                        || TO_CHAR(VE.DTABERTUR, 'DD/MM/YYYY HH24:MI:SS') CHAVE,
                                                        VE.CDVENDEDOR,
                                                        FILTROGER.CDPRODTAXASERV,
                                                        FILTROGER.CDPRODTAXAENTR,
                                                        FILTROGER.NMLOJA,
                                                        FILTROGER.NMFILIAL,
                                                        VE.VRREPIQUEVENDA
                                                    FROM
                                                        VENDA VE,
                                                        (
                                                            SELECT DISTINCT
                                                                C.CDFILIAL,
                                                                C.NMFILIAL,
                                                                C.CDCAIXA,
                                                                L.CDLOJA,
                                                                L.NMLOJA,
                                                                NVL(L.CDPRODTAXASERV, 'X') CDPRODTAXASERV,
                                                                NVL(L.CDPRODTAXAENTR, 'X') CDPRODTAXAENTR
                                                            FROM
                                                                LOJA L,
                                                                (
                                                                    SELECT DISTINCT
                                                                        F.CDFILIAL,
                                                                        F.NMFILIAL,
                                                                        CX.CDCAIXA,
                                                                        CX.NMCAIXA,
                                                                        CX.CDLOJA
                                                                    FROM
                                                                        CAIXA CX,
                                                                        (
                                                                            SELECT DISTINCT
                                                                                CDFILIAL,
                                                                                NMFILIAL
                                                                            FROM
                                                                                FILIAL
                                                                            WHERE
                                                                                ( ( INSTR(:CDFILIAL, CDFILIAL) <> 0 )
                                                                                  OR ( :TCDFILIAL = 'T' ) )
                                                                        ) F
                                                                    WHERE
                                                                        CX.CDFILIAL = F.CDFILIAL
                                                                        AND ( INSTR(:DTMOVTURCAIX, '_'
                                                                                                     || F.CDFILIAL
                                                                                                     || CDCAIXA) > 0
                                                                              OR :TDTMOVTURCAIX = 'T' )
                                                                ) C
                                                            WHERE
                                                                L.CDFILIAL = C.CDFILIAL
                                                                AND L.CDLOJA = C.CDLOJA
                                                                AND ( ( INSTR(:CDLOJA, L.CDFILIAL || L.CDLOJA) <> 0 )
                                                                      OR ( :TCDLOJA = 'T' ) )
                                                        ) FILTROGER
                                                    WHERE
                                                        VE.IDSITUVENDA = 'O'
                                                        AND VE.CDFILIAL = FILTROGER.CDFILIAL
                                                        AND VE.CDLOJA = FILTROGER.CDLOJA
                                                        AND VE.CDCAIXA = FILTROGER.CDCAIXA
                                                        AND VE.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                                                ) FILTROVENDA,
                                                ITEMVENDA   I,
                                                PRODUTO     P
                                            WHERE
                                                ( ( INSTR(:DTMOVTURCAIX, FILTROVENDA.CHAVE) > 0 )
                                                  OR ( :TDTMOVTURCAIX = 'T' ) )
                                                AND I.CDFILIAL = FILTROVENDA.CDFILIAL
                                                AND I.CDCAIXA = FILTROVENDA.CDCAIXA
                                                AND I.NRSEQVENDA = FILTROVENDA.NRSEQVENDA
                                                AND I.CDPRODUTO = P.CDPRODUTO
                                                AND NVL(I.CDVENDEDOR, FILTROVENDA.CDVENDEDOR) = V.CDVENDEDOR
                                                AND I.CDPRODUTO NOT IN (
                                                    FILTROVENDA.CDPRODTAXAENTR,
                                                    FILTROVENDA.CDPRODTAXASERV
                                                )
                                            GROUP BY
                                                FILTROVENDA.CDFILIAL,
                                                FILTROVENDA.NMFILIAL,
                                                FILTROVENDA.CDLOJA,
                                                FILTROVENDA.NMLOJA,
                                                I.CDPRODUTO,
                                                NVL(I.CDVENDEDOR, FILTROVENDA.CDVENDEDOR),
                                                FILTROVENDA.NRSEQVENDA,
                                                FILTROVENDA.CDPRODTAXASERV,
                                                FILTROVENDA.CDPRODTAXAENTR,
                                                FILTROVENDA.CDCAIXA,
                                                V.NMRAZSOCVEN,
                                                FILTROVENDA.VRREPIQUEVENDA,
                                                TRUNC(I.VRUNITVEND, 2),
                                                P.IDCOBTXSERV
                                                
                                                
                                        ) FILTROREL,
                                        (
                                            SELECT
                                                V.CDFILIAL,
                                                V.CDCAIXA,
                                                V.NRSEQVENDA,
                                                V.CDLOJA,
                                                I.VRUNITVEND,
                                                I.CDPRODUTO,
                                                NVL(I.CDVENDEDOR, V.CDVENDEDOR) CDVENDEDOR,
                                                SUM(TRUNC(I.QTPRODVEND *(I.VRUNITVEND + NVL(I.VRUNITVENDCL, 0)), 2) - NVL(I.VRDESITVEND
                                                , 0) + NVL(I.VRACRITVEND, 0)) VRPRODVEND
                                            FROM
                                                ITEMVENDA   I,
                                                VENDA       V
                                            WHERE
                                                I.CDFILIAL = V.CDFILIAL
                                                AND I.CDCAIXA = V.CDCAIXA
                                                AND I.NRSEQVENDA = V.NRSEQVENDA
                                                  AND ( ( INSTR(:CDPRODUTO, I.CDPRODUTO) > 0 ) OR ( :TCDPRODUTO = 'T' ) )
                                            GROUP BY
                                                V.CDFILIAL,
                                                V.CDCAIXA,
                                                V.NRSEQVENDA,
                                                V.CDLOJA,
                                                I.VRUNITVEND,
                                                I.CDPRODUTO,
                                                NVL(I.CDVENDEDOR, V.CDVENDEDOR)
                                        ) ITEMVEND,
                                        PRODUTO P
                                    WHERE
                                        ITEMVEND.CDFILIAL = FILTROREL.CDFILIAL
                                        AND ITEMVEND.NRSEQVENDA = FILTROREL.NRSEQVENDA
                                        AND ITEMVEND.CDLOJA = FILTROREL.CDLOJA
                                        AND ITEMVEND.CDVENDEDOR = FILTROREL.CDVENDEDOR
                                        AND ITEMVEND.VRUNITVEND = FILTROREL.VRUNIT
                                        AND ITEMVEND.CDPRODUTO = FILTROREL.CDPRODUTO
                                        AND P.CDPRODUTO = FILTROREL.CDPRODUTO
                                ) DADOSITEM
                                LEFT JOIN (
                                    SELECT V.CDFILIAL, V.CDCAIXA, V.NRSEQVENDA, V.DTABERTUR,
                                    SUM(NVL(I.VRACRITVEND,0)) AS VRGORJETA
                                    FROM VENDA V, ITEMVENDA I, LOJA L
                                    WHERE V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                                     AND ((INSTR(:CDFILIAL, V.CDFILIAL) <> 0) OR (:TCDFILIAL = 'T'))
                                     AND V.IDSITUVENDA = 'O'
                                     AND V.CDFILIAL    = I.CDFILIAL
                                     AND V.CDCAIXA     = I.CDCAIXA
                                     AND V.NRSEQVENDA  = I.NRSEQVENDA
                                     AND V.CDFILIAL    = L.CDFILIAL
                                     AND V.CDLOJA      = L.CDLOJA
                                     AND I.CDPRODUTO   = L.CDPRODTAXASERV
                                    GROUP BY V.CDFILIAL, V.CDCAIXA, V.NRSEQVENDA, V.DTABERTUR           
                                ) VALORGORJETA ON VALORGORJETA.CDFILIAL = DADOSITEM.CDFILIAL
                                                  AND VALORGORJETA.CDCAIXA = DADOSITEM.CDCAIXA
                                                  AND VALORGORJETA.NRSEQVENDA = DADOSITEM.NRSEQVENDA
                                LEFT JOIN 
                                (
                                SELECT V.CDFILIAL, V.NRSEQVENDA, V.CDCAIXA, SUM(NVL(I.VRACRITVEND,0)) VRTXENTREGA, V.DTABERTUR
                                  FROM ITEMVENDA I, VENDA V, LOJA L
                                 WHERE I.CDFILIAL = V.CDFILIAL
                                   AND I.CDCAIXA    = V.CDCAIXA
                                   AND I.NRSEQVENDA = V.NRSEQVENDA
                                   AND V.CDLOJA     = L.CDLOJA
                                   AND I.CDLOJA     = L.CDLOJA
                                   AND V.CDFILIAL   = L.CDFILIAL
                                   AND I.CDPRODUTO IN (L.CDPRODTAXAENTR)
                                 GROUP BY V.CDFILIAL, V.NRSEQVENDA, V.CDCAIXA, V.DTABERTUR
                                ) VRTXENTREGA ON VRTXENTREGA.CDFILIAL = DADOSITEM.CDFILIAL
                                                  AND VRTXENTREGA.CDCAIXA = DADOSITEM.CDCAIXA
                                                  AND VRTXENTREGA.NRSEQVENDA = DADOSITEM.NRSEQVENDA,
                                (
                                    SELECT
                                        V.CDFILIAL,
                                        V.NRSEQVENDA,
                                        V.CDCAIXA,
                                        SUM(TRUNC(I.QTPRODVEND *(I.VRUNITVEND + NVL(I.VRUNITVENDCL, 0)), 2) - NVL(I.VRDESITVEND, 0) +
                                        NVL(I.VRACRITVEND, 0)) VRITENS
                                    FROM
                                        ITEMVENDA   I,
                                        VENDA       V,
                                        LOJA        L,
                                        PRODUTO     P
                                    WHERE
                                        I.CDFILIAL = V.CDFILIAL
                                        AND I.CDCAIXA = V.CDCAIXA
                                        AND I.NRSEQVENDA = V.NRSEQVENDA
                                        AND V.CDLOJA = L.CDLOJA
                                        AND I.CDLOJA = L.CDLOJA
                                        AND V.CDFILIAL = L.CDFILIAL
                                        AND I.CDPRODUTO <> NVL(L.CDPRODTAXAENTR, 'X')
                                        AND I.CDPRODUTO <> NVL(L.CDPRODTAXASERV, 'X')
                                        AND P.CDPRODUTO = I.CDPRODUTO
                                        AND P.IDCOBTXSERV = 'S'
                                    GROUP BY
                                        V.CDFILIAL,
                                        V.NRSEQVENDA,
                                        V.CDCAIXA
                               ) VALORGERALVENDA
                            WHERE
                                VALORGERALVENDA.CDFILIAL = DADOSITEM.CDFILIAL
                                AND VALORGERALVENDA.CDCAIXA = DADOSITEM.CDCAIXA
                                AND VALORGERALVENDA.NRSEQVENDA = DADOSITEM.NRSEQVENDA
                        ) RELATORIO
                    GROUP BY
                        RELATORIO.CDFILIAL,
                        RELATORIO.NMFILIAL,
                        RELATORIO.CDLOJA,
                        RELATORIO.NMLOJA,
                        RELATORIO.CDARVPROD,
                        RELATORIO.NMPRODUTO,
                        RELATORIO.CDVENDEDOR,
                        RELATORIO.NMRAZSOCVEN,
                        RELATORIO.VRUNIT,
                        RELATORIO.NRSEQVENDA,
                        NVL(RELATORIO.VRREPIQUEVENDA, 0),
                        RELATORIO.IDCOBTXSERV,                       
                        RELATORIO.CDPRODUTO,
                        RELATORIO.CDPRODNIVANTE
                ) CONSOLIDADO
            GROUP BY
                CONSOLIDADO.CDFILIAL,
                CONSOLIDADO.NMFILIAL,
                CONSOLIDADO.CDLOJA,
                CONSOLIDADO.NMLOJA,
                CONSOLIDADO.CDARVPROD,
                CONSOLIDADO.NMPRODUTO,
                CONSOLIDADO.CDVENDEDOR,
                CONSOLIDADO.NMRAZSOCVEN,
                CONSOLIDADO.VRUNIT,
                CONSOLIDADO.CDPRODUTO,
                CONSOLIDADO.CDPRODNIVANTE
        ) FINAL
    ORDER BY
        CDFILIAL,
        CDLOJA,
        CDVENDEDOR,
        CDARVPROD
     )TOTAL,
     PRODUTO PP,
     PRODUTO PPP
     WHERE
     TOTAL.CDPRODNIVANTE = PP.CDARVPROD
     AND PP.CDPRODNIVANTE = PPP.CDARVPROD
     AND ( ( INSTR(:CDPRODUTOAVO, PPP.CDARVPROD) > 0 ) OR ( :TCDPRODUTOAVO = 'T' ) ) 

    ";

    const REL_PRODUTIVIDADE_VENDEDOR_SINTETICO = "
        SELECT A.LABELLOJA,  A.GARCON,  A.LABELFILIAL,  A.CDFILIAL,  A.NMLOJA, A.CDVENDEDOR,
               A.NMRAZSOCVEN,  SUM(A.VRGORJETA) AS VRGORJETA, SUM(A.VRTXENTREGA) AS VRTXENTREGA, SUM(A.QTPRODVEND) AS QTPRODVEND,
               SUM(A.VRFINALITEM) + SUM(VRGORJETA) + SUM(VRTXENTREGA) AS VRFINALITEM,  SUM(A.DES) AS DES,  SUM(A.ACR) AS ACR, 
               SUM(VRREPIQUEVENDA) AS VRREPIQUEVENDA , VRTOTREP AS VRREPITEM, SUM(A.VRLIQUIDO) + SUM(VRGORJETA) + SUM(VRTXENTREGA) VRLIQUIDO
        FROM
          (SELECT 'TODAS'  AS LABELFILIAL,
                  (CDLOJA || ' - ' || NMLOJA)  AS LABELLOJA, NMRAZSOCVEN AS GARCON,
                  FINAL.*, SUM(VRREPITEM) OVER (PARTITION BY CDFILIAL, CDLOJA, CDVENDEDOR) VRTOTREP, 
                  FINAL.VRPRODVENDA + FINAL.VRREPITEM VRFINALITEM, FINAL.VRPRODVENDA VRLIQUIDO
          FROM
            (SELECT CONSOLIDADO.CDFILIAL, CONSOLIDADO.NMFILIAL, CONSOLIDADO.CDLOJA, CONSOLIDADO.NMLOJA, CONSOLIDADO.CDARVPROD, CONSOLIDADO.NMPRODUTO,
                    CONSOLIDADO.CDVENDEDOR, CONSOLIDADO.NMRAZSOCVEN, CONSOLIDADO.VRUNIT, NVL(SUM(((VRGORJETAVENDA - VRREPIQUEVENDA) * VRPRODVENDA)/ VRGERALITEMVENDA), 0) VRGORJETA, 
                    NVL(SUM(((VRTXENTREGAVENDA - VRREPIQUEVENDA) * VRPRODVENDA)/ VRGERALITEMVENDA), 0) VRTXENTREGA, 
                    SUM(QTPRODVEND) QTPRODVEND, SUM(ACR) ACR, SUM(DES) DES, SUM(VRPRODVENDA) VRPRODVENDA, SUM(VRREPITEMTEMP / VRGERALITEMVENDA) AS VRREPITEM, NVL(SUM(VRREPIQUEVENDA),0) AS VRREPIQUEVENDA
            FROM
              (SELECT RELATORIO.CDFILIAL, RELATORIO.NMFILIAL, RELATORIO.CDLOJA, RELATORIO.NMLOJA, RELATORIO.CDARVPROD, RELATORIO.NMPRODUTO, RELATORIO.CDVENDEDOR,
                      RELATORIO.NMRAZSOCVEN, RELATORIO.VRUNIT, RELATORIO.NRSEQVENDA, NVL(RELATORIO.VRREPIQUEVENDA, 0) VRREPIQUEVENDA, SUM(RELATORIO.QTPRODVEND) QTPRODVEND,
                      SUM(RELATORIO.ACR) ACR, SUM(RELATORIO.DES) DES, SUM(RELATORIO.VRPRODVENDA) VRPRODVENDA, SUM(RELATORIO.VRGORJETA) VRGORJETAVENDA, SUM(RELATORIO.VRTXENTREGA) VRTXENTREGAVENDA,
                      NVL(SUM(RELATORIO.VRREPIQUEVENDA * RELATORIO.VRPRODVENDA), 0) VRREPITEMTEMP, SUM(RELATORIO.VRITENS) VRGERALITEMVENDA
              FROM
                (SELECT DISTINCT DADOSITEM.CDFILIAL, DADOSITEM.NMFILIAL, DADOSITEM.CDLOJA, DADOSITEM.NMLOJA, DADOSITEM.CDARVPROD, DADOSITEM.NMPRODUTO, DADOSITEM.CDVENDEDOR,
                        DADOSITEM.NMRAZSOCVEN, DADOSITEM.QTPRODVEND, DADOSITEM.ACR, DADOSITEM.DES, DADOSITEM.VRPRODVENDA, DADOSITEM.VRUNIT, DADOSITEM.VRREPIQUEVENDA,
                        DADOSITEM.NRSEQVENDA, VRITENS, VRGORJETA, VRTXENTREGA
                FROM
                  (SELECT DISTINCT FILTROREL.CDFILIAL, FILTROREL.NMFILIAL, FILTROREL.CDLOJA, FILTROREL.NMLOJA, FILTROREL.CDPRODUTO, P.CDARVPROD, P.NMPRODUTO, FILTROREL.CDVENDEDOR,
                          FILTROREL.CDPRODTAXASERV, FILTROREL.CDPRODTAXAENTR, FILTROREL.NMRAZSOCVEN, FILTROREL.CDCAIXA, FILTROREL.VRREPIQUEVENDA, FILTROREL.QTPRODVEND,
                          FILTROREL.ACR, FILTROREL.DES, FILTROREL.VRPRODVENDA, FILTROREL.NRSEQVENDA, FILTROREL.VRUNIT
                  FROM
                    (SELECT DISTINCT FILTROVENDA.CDFILIAL, FILTROVENDA.NMFILIAL, FILTROVENDA.CDLOJA, FILTROVENDA.NMLOJA, I.CDPRODUTO, NVL(I.CDVENDEDOR, FILTROVENDA.CDVENDEDOR) CDVENDEDOR,
                            FILTROVENDA.NRSEQVENDA, FILTROVENDA.CDPRODTAXASERV, FILTROVENDA.CDPRODTAXAENTR, FILTROVENDA.CDCAIXA, V.NMRAZSOCVEN, FILTROVENDA.VRREPIQUEVENDA,
                            TRUNC(I.VRUNITVEND,2) AS VRUNIT, SUM(I.QTPRODVEND) QTPRODVEND, SUM(I.VRACRITVEND) ACR, SUM(I.VRDESITVEND) DES, 
                            SUM(TRUNC(I.QTPRODVEND * (I.VRUNITVEND + NVL(I.VRUNITVENDCL,0)),2) - NVL(I.VRDESITVEND,0) + NVL(I.VRACRITVEND,0)) AS VRPRODVENDA
                    FROM
                      (SELECT CDVENDEDOR, NMRAZSOCVEN
                         FROM VENDEDOR
                        WHERE ((INSTR(:CDVENDEDOR, CDVENDEDOR) > 0) OR (:TCDVENDEDOR = 'T'))
                      ) V,
                      (SELECT DISTINCT VE.CDFILIAL, VE.CDCAIXA, VE.CDLOJA, VE.NRSEQVENDA, FILTROGER.CDFILIAL ||VE.CDCAIXA ||TO_CHAR(VE.DTABERTUR, 'DD/MM/YYYY HH24:MI:SS') CHAVE,
                              VE.CDVENDEDOR, FILTROGER.CDPRODTAXASERV, FILTROGER.CDPRODTAXAENTR, FILTROGER.NMLOJA, FILTROGER.NMFILIAL, VE.VRREPIQUEVENDA
                         FROM VENDA VE,
                              (SELECT DISTINCT C.CDFILIAL, C.NMFILIAL, C.CDCAIXA, L.CDLOJA, L.NMLOJA, NVL(L.CDPRODTAXASERV, 'X') CDPRODTAXASERV, 
                                      NVL(L.CDPRODTAXAENTR, 'X') CDPRODTAXAENTR
                                 FROM LOJA L,
                                      (SELECT DISTINCT F.CDFILIAL, F.NMFILIAL, CX.CDCAIXA, CX.NMCAIXA, CX.CDLOJA
                                         FROM CAIXA CX,
                                              (SELECT DISTINCT CDFILIAL, NMFILIAL
                                                 FROM FILIAL
                                                WHERE ((INSTR(:CDFILIAL, CDFILIAL) <> 0) OR (:TCDFILIAL = 'T'))
                                              ) F
                                        WHERE CX.CDFILIAL = F.CDFILIAL
                                          AND (INSTR(:DTMOVTURCAIX, '_' ||F.CDFILIAL ||CDCAIXA) > 0 OR :TDTMOVTURCAIX = 'T') 
                                      ) C
                                WHERE L.CDFILIAL = C.CDFILIAL
                                  AND L.CDLOJA     = C.CDLOJA
                                  AND ((INSTR(:CDLOJA, L.CDFILIAL ||L.CDLOJA) <> 0) OR (:TCDLOJA   = 'T')) 
                              ) FILTROGER
                        WHERE VE.IDSITUVENDA = 'O'
                          AND VE.CDFILIAL      = FILTROGER.CDFILIAL
                          AND VE.CDLOJA        = FILTROGER.CDLOJA
                          AND VE.CDCAIXA       = FILTROGER.CDCAIXA
                          AND VE.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                      ) FILTROVENDA,
                        ITEMVENDA I
                WHERE ((INSTR(:DTMOVTURCAIX, FILTROVENDA.CHAVE) > 0) OR (:TDTMOVTURCAIX = 'T'))
                  AND I.CDFILIAL = FILTROVENDA.CDFILIAL
                  AND I.CDCAIXA = FILTROVENDA.CDCAIXA
                  AND I.NRSEQVENDA = FILTROVENDA.NRSEQVENDA
                  AND NVL(I.CDVENDEDOR, FILTROVENDA.CDVENDEDOR)   = V.CDVENDEDOR
                  AND I.CDPRODUTO NOT IN (FILTROVENDA.CDPRODTAXAENTR, FILTROVENDA.CDPRODTAXASERV)
                GROUP BY FILTROVENDA.CDFILIAL, FILTROVENDA.NMFILIAL, FILTROVENDA.CDLOJA, FILTROVENDA.NMLOJA, I.CDPRODUTO, NVL(I.CDVENDEDOR, FILTROVENDA.CDVENDEDOR),
                         FILTROVENDA.NRSEQVENDA, FILTROVENDA.CDPRODTAXASERV, FILTROVENDA.CDPRODTAXAENTR, FILTROVENDA.CDCAIXA, V.NMRAZSOCVEN, FILTROVENDA.VRREPIQUEVENDA,
                         TRUNC(I.VRUNITVEND,2)
                  ) FILTROREL,
                  (SELECT V.CDFILIAL, V.CDCAIXA, V.NRSEQVENDA, V.CDLOJA, I.VRUNITVEND, I.CDPRODUTO, NVL(I.CDVENDEDOR, V.CDVENDEDOR) CDVENDEDOR,
                          SUM(TRUNC(I.QTPRODVEND * (I.VRUNITVEND + NVL(I.VRUNITVENDCL,0)),2) - NVL(I.VRDESITVEND,0) + NVL(I.VRACRITVEND,0)) VRPRODVEND
                     FROM ITEMVENDA I, VENDA V
                    WHERE I.CDFILIAL = V.CDFILIAL
                      AND I.CDCAIXA    = V.CDCAIXA
                      AND I.NRSEQVENDA = V.NRSEQVENDA
                      AND ((INSTR(:CDPRODUTO, I.CDPRODUTO) > 0) OR (:TCDPRODUTO = 'T'))
                    GROUP BY V.CDFILIAL, V.CDCAIXA, V.NRSEQVENDA, V.CDLOJA, I.VRUNITVEND, I.CDPRODUTO, NVL(I.CDVENDEDOR, V.CDVENDEDOR)
                   ) ITEMVEND, PRODUTO P, PRODUTO PP, PRODUTO PPP
               WHERE ITEMVEND.CDFILIAL = FILTROREL.CDFILIAL
                 AND ITEMVEND.NRSEQVENDA = FILTROREL.NRSEQVENDA
                 AND ITEMVEND.CDLOJA     = FILTROREL.CDLOJA
                 AND ITEMVEND.CDVENDEDOR = FILTROREL.CDVENDEDOR
                 AND ITEMVEND.VRUNITVEND = FILTROREL.VRUNIT
                 AND ITEMVEND.CDPRODUTO  = FILTROREL.CDPRODUTO
                 AND P.CDPRODUTO         = FILTROREL.CDPRODUTO
                 AND P.CDPRODNIVANTE     = PP.CDARVPROD
                 AND PP.CDPRODNIVANTE     = PPP.CDARVPROD
                 AND ((INSTR(:CDPRODUTOAVO, PPP.CDARVPROD) > 0) OR (:TCDPRODUTOAVO = 'T'))
              ) DADOSITEM
           LEFT JOIN (
                                    SELECT V.CDFILIAL, V.CDCAIXA, V.NRSEQVENDA, V.DTABERTUR,
                                    SUM(NVL(I.VRACRITVEND,0)) AS VRGORJETA
                                    FROM VENDA V, ITEMVENDA I, LOJA L
                                    WHERE V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                                     AND ((INSTR(:CDFILIAL, V.CDFILIAL) <> 0) OR (:TCDFILIAL = 'T'))
                                     AND V.IDSITUVENDA = 'O'
                                     AND V.CDFILIAL    = I.CDFILIAL
                                     AND V.CDCAIXA     = I.CDCAIXA
                                     AND V.NRSEQVENDA  = I.NRSEQVENDA
                                     AND V.CDFILIAL    = L.CDFILIAL
                                     AND V.CDLOJA      = L.CDLOJA
                                     AND I.CDPRODUTO   = L.CDPRODTAXASERV
                                    GROUP BY V.CDFILIAL, V.CDCAIXA, V.NRSEQVENDA, V.DTABERTUR           
                                ) VALORGORJETA ON VALORGORJETA.CDFILIAL = DADOSITEM.CDFILIAL
                                                  AND VALORGORJETA.CDCAIXA = DADOSITEM.CDCAIXA
                                                  AND VALORGORJETA.NRSEQVENDA = DADOSITEM.NRSEQVENDA
                                LEFT JOIN 
                                (
                                SELECT V.CDFILIAL, V.NRSEQVENDA, V.CDCAIXA, SUM(NVL(I.VRACRITVEND,0)) VRTXENTREGA, V.DTABERTUR
                                  FROM ITEMVENDA I, VENDA V, LOJA L
                                 WHERE I.CDFILIAL = V.CDFILIAL
                                   AND I.CDCAIXA    = V.CDCAIXA
                                   AND I.NRSEQVENDA = V.NRSEQVENDA
                                   AND V.CDLOJA     = L.CDLOJA
                                   AND I.CDLOJA     = L.CDLOJA
                                   AND V.CDFILIAL   = L.CDFILIAL
                                   AND I.CDPRODUTO IN (L.CDPRODTAXAENTR)
                                 GROUP BY V.CDFILIAL, V.NRSEQVENDA, V.CDCAIXA, V.DTABERTUR
                                ) VRTXENTREGA ON VRTXENTREGA.CDFILIAL = DADOSITEM.CDFILIAL
                                                  AND VRTXENTREGA.CDCAIXA = DADOSITEM.CDCAIXA
                                                  AND VRTXENTREGA.NRSEQVENDA = DADOSITEM.NRSEQVENDA,
                     (SELECT V.CDFILIAL, V.NRSEQVENDA, V.CDCAIXA, 
                             SUM(TRUNC(I.QTPRODVEND * (I.VRUNITVEND + NVL(I.VRUNITVENDCL,0)),2) - NVL(I.VRDESITVEND,0) + NVL(I.VRACRITVEND,0)) VRITENS
                        FROM ITEMVENDA I, VENDA V, LOJA L
                       WHERE I.CDFILIAL = V.CDFILIAL
                         AND I.CDCAIXA    = V.CDCAIXA
                         AND I.NRSEQVENDA = V.NRSEQVENDA
                         AND V.CDLOJA     = L.CDLOJA
                         AND I.CDLOJA     = L.CDLOJA
                         AND V.CDFILIAL   = L.CDFILIAL
                         AND I.CDPRODUTO <> NVL(L.CDPRODTAXAENTR, 'X')
                         AND I.CDPRODUTO <> NVL(L.CDPRODTAXASERV, 'X')
                       GROUP BY V.CDFILIAL, V.NRSEQVENDA, V.CDCAIXA
                      ) VALORGERALVENDA
                WHERE VALORGERALVENDA.CDFILIAL = DADOSITEM.CDFILIAL
                  AND VALORGERALVENDA.CDCAIXA    = DADOSITEM.CDCAIXA
                  AND VALORGERALVENDA.NRSEQVENDA = DADOSITEM.NRSEQVENDA
                ) RELATORIO
            GROUP BY RELATORIO.CDFILIAL, RELATORIO.NMFILIAL, RELATORIO.CDLOJA, RELATORIO.NMLOJA, RELATORIO.CDARVPROD, RELATORIO.NMPRODUTO, RELATORIO.CDVENDEDOR, RELATORIO.NMRAZSOCVEN,
                     RELATORIO.VRUNIT, RELATORIO.NRSEQVENDA, NVL(RELATORIO.VRREPIQUEVENDA, 0)
               ) CONSOLIDADO
           GROUP BY CONSOLIDADO.CDFILIAL, CONSOLIDADO.NMFILIAL, CONSOLIDADO.CDLOJA, CONSOLIDADO.NMLOJA, CONSOLIDADO.CDARVPROD, CONSOLIDADO.NMPRODUTO, CONSOLIDADO.CDVENDEDOR,
                    CONSOLIDADO.NMRAZSOCVEN, CONSOLIDADO.VRUNIT
              ) FINAL
          ORDER BY CDFILIAL, CDLOJA, CDVENDEDOR, CDARVPROD
             ) A
        GROUP BY A.LABELLOJA, A.LABELFILIAL, A.GARCON, A.CDFILIAL, A.NMLOJA, A.CDVENDEDOR, A.NMRAZSOCVEN, A.VRTOTREP
        ORDER BY A.CDVENDEDOR, A.NMRAZSOCVEN

    ";
    
}