<?php
namespace Teknisa\MAN\Services;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;

class TabelaPrecoGeralService{
    
    protected $conn;
    protected $entityManager;
    
     // importação concluída
        const SUCCESS_PC = "SUCCESS_IMP";
        // erro na exportação
        const ERROR_PC = "ERROR_IMP";
        // Tabela ja existe
        const ALREADY = "ALREADY";
        
        const IMPORT_CSV = "csv";
        
        const IMPORT_XLS = "xls";
        
        const IMPORT_XLSX = "lsx";
        //
        
       const T_PRODUCT = 'T';
        
       const WITHOUTVIG_PC = 'WITHOUTVIG_PC';
    
       const PRICECHART = 'PRICECHART';
    
       const NEWPRICECHART = 'NEWPRICECHART';
        
    public function __construct(Connection $conn, EntityManager $entityManager) {
        $this->conn = $conn;
        $this->entityManager = $entityManager;
    }
    
    public function controlTransaction($type){
    // controla transação com banco    
        try {
            switch ($type) {
                case 'begin':
                // inicia transação sem auto-commit
                    $this->entityManager->getConnection()->beginTransaction();
                    break;
                case 'commit':
                // salva transação
                    $this->entityManager->getConnection()->commit();
                    break;
                case 'rollback':
                // descarta transação
                    $this->entityManager->getConnection()->rollBack();
                    break;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function findVigencias($data){
         $search = NULL;
        $indexFind = 'GROUPED_LABEL|DTINIVGPREC|DTFINVGPREC|STATUS_VIGENCIA';
        if(array_key_exists($indexFind, $data)){
            $search = $data[$indexFind][0]['_ALL'];
        }
        $params = array(
            ':NRORG'      =>  $data['NRORG'],
            ':SEARCH' =>  $search
        );
        return $this->conn->fetchAll(self::GET_VIGENCIAS,$params);
    }
    
    public function findUnidades($params){
       
        $search = NULL;
        $indexFind = 'CDFILIAL|NMFILIAL';
        if(array_key_exists($indexFind, $params)){
            $search = $params[$indexFind][0]['_ALL'];
        }
        $params = array(
            ':CDTABEPREC'      =>  $params['CDTABEPREC'],
            ':DTINIVGPREC'      =>  $params['DTINIVGPREC'],
            ':NRORG'         =>  $params['NRORG'],
            ':SEARCH'           => $search
        );
        return $this->conn->fetchAll(self::GET_UNIDADES,$params);
    }
    
    public function saveUnidades($row){
        self::controlTransaction('begin');
        foreach($row['CDFILIAL'] as $key => $CDFILIAL){
            $params = array(
                ':CDFILIAL'        =>  $CDFILIAL,
                ':CDTABEPREC'      =>  $row['CDTABEPREC'],
                ':CDOPERADOR'      =>  $row['CDOPERADOR']
            );
            $this->conn->executeQuery(self::SAVE_UNIDADES,$params);
            if ($key == 100) {
                self::controlTransaction('commit');
                self::controlTransaction('begin');
            }
        }
        self::controlTransaction('commit');
        return array();
    }
    
    public function deleteUnidade($rows){
        foreach($rows as $row){
            $params = array(
                ':CDFILIAL' => $row['CDFILIAL'],
                ':CDTABEPREC' => $row['CDTABEPREC']
            );
            $this->conn->executeQuery(self::REMOVE_UNIDADES,$params);    
        }
        return array();
    }
    
    public function findProdutos($data){
        $search = NULL;
        
        
        $indexFind = 'CDARVPROD|NMPRODUTO|VRPRECITEM|VRPRESUGITEM|VRPRECITEMCL|VRCUSTITEM|HRINIVENPROD|HRFIMVENPROD';
        if(array_key_exists($indexFind, $data)){
            $search = $data[$indexFind][0]['_ALL'];
        }
        if (isset($data['INTERVALISTA']) && $data['INTERVALISTA'] == 'I'){
           if (empty($data['CDARVPRODF'])){
                $data['CDARVPRODF'] = $data['CDARVPRODI'];
           }
           $data['TCDPRODUTO'] = null;
           $data['CDPRODLIST'] = null;
           $data['PRODNIV'] = null;
        }elseif (isset($data['INTERVALISTA']) && $data['INTERVALISTA'] == 'D') {
           $data['PRODNIV'] = str_replace('%', '', str_replace('.', '', $data['PRODNIV'])).'%';
           $data['TCDPRODUTO'] = null;
           $data['CDPRODLIST'] = null;
           $data['CDARVPRODF'] = null;
           $data['CDARVPRODI'] = null;
        }
        elseif (isset($data['INTERVALISTA']) && $data['INTERVALISTA'] == 'L'){
           $data['CDPRODLIST'] = implode('_', $data['CDPRODUTOL']);
           $data['TCDPRODUTO'] = null;
           $data['CDARVPRODF'] = null;
           $data['CDARVPRODI'] = null;
           $data['PRODNIV'] = null;
        }
        else{
           $data['TCDPRODUTO'] = 'T';
           $data['CDPRODLIST'] = null;
           $data['CDARVPRODF'] = null;
           $data['CDARVPRODI'] = null;
           $data['PRODNIV'] = null;
        }
        $params = array(
            ':CDTABEPREC'       =>  $data['CDTABEPREC'],
            ':DTINIVGPREC'      =>  $data['DTINIVGPREC'],
            ':CDNVPRODUTO'      =>  $data['CDNVPRODUTO'],
            ':NRORG'            =>  $data['NRORG'],
            ':TCDPRODUTO'       => $data['TCDPRODUTO'],
            ':CDPRODLIST'       => $data['CDPRODLIST'],
            ':CDARVPRODF'       => $data['CDARVPRODF'],
            ':CDARVPRODI'       => $data['CDARVPRODI'],
            ':PRODNIV'          => $data['PRODNIV'],
            ':SEARCH'           => $search
        );
        
        return $this->conn->fetchAll(self::GET_PROD_TABPREC,$params);
    }
    
    public function getNrConfig($CDFILIAL,$CDGRPRODPDV, $NRORG){
        
        $params = array(
            ':P_CDFILISUBGR'    =>  $CDFILIAL,
            ':P_CDGRUPPROD'     =>  $CDGRPRODPDV,
            ':P_NRORG'          =>  $NRORG
        );
        
        $result = $this->conn->fetchAll(self::GET_NRCONFIG,$params);
        
        return $result;
    }
    
    public function findVigenciasImport($params){
        $CDFILIAL      = $params[0]['value'];
        $P_CDTABEPREC  = $params[1]['value'];
        $P_DTINIVGPREC = $params[2]['value'];
        
        $params = array(
            ':P_CDFILIAL'    =>  $CDFILIAL,
            ':P_CDTABEPREC'  =>  $P_CDTABEPREC,
            ':P_DTINIVGPREC' =>   $P_DTINIVGPREC
            
        );
        
        $result = $this->conn->fetchAll(self::GET_VIGENCIA_BYTABELAPRECO_BYFILIAL,$params);
        
        return $result;
    }
    
    public function validImportPriceChart($params){
        $CDFILIAL          = $params[0]['value'];
        $P_CDTABEPREC      = $params[1]['value'];
        $P_DTINIVGPRECORIG = substr($params[2]['value'], 3,10);
        $P_DTINIVGPRECDEST = $params[3]['value'];
        
        if($P_DTINIVGPRECORIG == ""){
            throw new \Exception('EMPTYFIELD',1);
        }
        
        $params = array(
            ':P_CDFILIAL'    =>  $CDFILIAL,
            ':P_CDTABEPREC'  =>  $P_CDTABEPREC,
            ':P_DTINIVGPREC' =>   $P_DTINIVGPRECORIG
            
        );
        $resultOri = $this->conn->fetchAll(self::CHECK_PRECO_VIGENCIA_EXISTS,$params);
        

        $params = array(
            ':P_CDFILIAL'    =>  $CDFILIAL,
            ':P_CDTABEPREC'  =>  $P_CDTABEPREC,
            ':P_DTINIVGPREC' =>   $P_DTINIVGPRECDEST
            
        );
        $resultDest = $this->conn->fetchAll(self::CHECK_PRECO_VIGENCIA_EXISTS,$params);
        return $resultDest;
    }
    
    public function importItensVigencia($params){
        $P_CDFILIAL        = $params[0]['value'];
        $P_CDTABEPREC      = $params[1]['value'];
        $P_DTINIVGPRECORIG = substr($params[2]['value'], 3,10);
        $P_DTINIVGPRECDEST = $params[3]['value'];
        $P_DTFINVGPRECDEST = $params[4]['value'];
        $ISPOPULADA        = $params[5]['value'];
        if($ISPOPULADA == "S"){
            $paramsDelete = array(
                ':P_CDFILIAL'    =>  $P_CDFILIAL,
                ':P_CDTABEPREC'  =>  $P_CDTABEPREC,
                ':P_DTINIVGPREC' =>  $P_DTINIVGPRECDEST
            );
            $this->conn->executeQuery(self::DELETE_ITEM_VIGENCIADES_1,$paramsDelete);
            $this->conn->executeQuery(self::DELETE_ITEM_VIGENCIADES_2,$paramsDelete);
        }
        
        $paramsInsertPreco = array(
            ':P_CDFILIAL'    =>  $P_CDFILIAL,
            ':P_CDTABEPREC'  =>  $P_CDTABEPREC,
            ':P_DTINIVGDEST' =>  $P_DTINIVGPRECDEST,
            ':P_DTINIVGORIG' =>  $P_DTINIVGPRECORIG
        );
        $this->conn->executeQuery(self::INSERT_ITEM_VIGENCIADES_1,$paramsInsertPreco);
        
        $paramsInsertPrecoVenda = array(
            ':P_CDFILIAL'    =>  $P_CDFILIAL,
            ':P_CDTABEPREC'  =>  $P_CDTABEPREC,
            ':P_DTINIVGDEST' =>  $P_DTINIVGPRECDEST,
            ':P_DTFINVGDEST' =>  $P_DTFINVGPRECDEST,
            ':P_DTINIVGORIG' =>  $P_DTINIVGPRECORIG
        );
        $this->conn->executeQuery(self::INSERT_ITEM_VIGENCIADES_2,$paramsInsertPrecoVenda);
    }

    public function insertTabelaPreco($CDFILIAL,$CDTABEPREC,$NMTABEPREC,$IDATIVO,$CDOPERULTATU,$DTULTATU,$NRORGULTATU,$CDOPERINCLUSAO,$DTINCLUSAO,$NRORG,$NRORGINCLUSAO){

       $params = array(
            'CDFILIAL'          =>  $CDFILIAL,
            'CDTABEPREC'        =>  $CDTABEPREC,
            'NMTABEPREC'        =>  $NMTABEPREC,
            'IDATIVO'           =>  $IDATIVO,
            'CDOPERULTATU'      =>  $CDOPERULTATU,
            'DTULTATU'          =>  $DTULTATU,
            'NRORGULTATU'       =>  $NRORGULTATU,
            'CDOPERINCLUSAO'    =>  $CDOPERINCLUSAO,
            'DTINCLUSAO'        =>  $DTINCLUSAO,
            'NRORG'             =>  $NRORG,
            'NRORGINCLUSAO'     =>  $NRORGINCLUSAO
        ); 
        
        $result = $this->conn->executeQuery(self::INSERT_TABEPREC,$params);
    
    }
    
    public function updateTABEPREC($NMTABEPREC,$NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU,$CDTABEPREC){
        $params = array(
            'NRORG'         =>  $NRORG,
            'CDTABEPREC'    =>  $CDTABEPREC,
            'CDOPERULTATU'  =>  $CDOPERULTATU,
            'NMTABEPREC'   => $NMTABEPREC,
            '$DTULTATU'     => $DTULTATU,
            'NRORGULTATU'   => $NRORGULTATU,
        );
        
        $result = $this->conn->executeQuery(self::UPDATE_TABEPREC,$params);
    }
    
    
    public function insertPrecoItem($params,$data){
        $this->entityManager->getConnection()->beginTransaction();
        try{
            $i = 0;
            $data = $this->conn->fetchAll(self::GET_INTERVALO_CAD_AUTOMATICO,$params);
            foreach ($data as $value) {
                if($value['CDARVPROD'] >= $params['CDPRODUTOINI'] && $value['CDARVPROD'] <= $params['CDPRODUTOFIN'] ){
                    $params = array_merge($params,array(
                        'CDPRODUTO'         =>  $value['CDPRODUTO'],
                        'CDPRPAITABPR'      =>  $value['CDPRODUTO']
                    ));
                    $prodHasPrice = $this->conn->fetchAssoc(self::GET_ITEMPRECO,$params);
                    if($prodHasPrice){
                         $result = $this->conn->executeQuery(self::UPDATE_ITEMPRECO,$params);
                    } else {
                        $result = $this->conn->executeQuery(self::INSERT_ITEMPRECO,$params);
                    }
                    $i++;
                }
			}
            $this->entityManager->getConnection()->commit();
            return $i;
        }catch(Exception $e){
            $this->entityManager->getConnection()->rollBack();
            throw $e->getMessage;
        }
    }
    
    public function insertPrecoItemInline($produto){
       $this->conn->executeQuery(self::INSERT_ITEMPRECO,$produto);
    }
    
    public function InsertVigencia($CDTABEPREC,$DTINIVGPREC,$DTFINVGPREC,$CDOPERINCLUSAO,$DTINCLUSAO,$NRORGINCLUSAO,$NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU){
        $params = array(
            ':CDTABEPREC'        =>  $CDTABEPREC,
            ':DTINIVGPREC'       =>  $DTINIVGPREC,
            ':DTFINVGPREC'       =>  $DTFINVGPREC,
            ':CDOPERINCLUSAO'    =>  $CDOPERINCLUSAO,
            ':DTINCLUSAO'        =>  $DTINCLUSAO,
            ':NRORGINCLUSAO'     =>  $NRORGINCLUSAO,
            ':NRORG'             =>  $NRORG,
            ':CDOPERULTATU'      =>  $CDOPERULTATU,
            ':DTULTATU'          =>  $DTULTATU,
            ':NRORGULTATU'       =>  $NRORGULTATU
        );
        $result = $this->conn->executeQuery(self::INSERT_VIGENCIA,$params);
    }
    
    public function updateVigencia($CDTABEPREC,$DTINIVGPREC,$DTFINVGPREC, $OLD_DTINIVGPREC, $OLD_DTFINVGPREC , $NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU){
        $params = array(
            'CDTABEPREC'    =>  $CDTABEPREC,
            'DTINIVGPREC'   =>  $DTINIVGPREC,
            'DTFINVGPREC'   =>  $DTFINVGPREC,
            'NRORG'         =>  $NRORG,
            'CDOPERULTATU'  =>  $CDOPERULTATU,
            'DTULTATU'      =>  $DTULTATU,
            'NRORGULTATU'   =>  $NRORGULTATU, 
            'OLD_DTINIVGPREC' => $OLD_DTINIVGPREC, 
            'OLD_DTFINVGPREC' => $OLD_DTFINVGPREC
        );
        
        $result = $this->conn->executeQuery(self::UPDATE_VIGENCIA,$params);
    }
    
    public function deleteVigencia($NRORG,$CDTABEPREC,$DTINIVGPREC){
        $params = array(
            ':NRORG'        =>  $NRORG,
            ':CDTABEPREC'   =>  $CDTABEPREC,
            ':DTINIVGPREC'  =>  $DTINIVGPREC
        );
        if($params[":DTINIVGPREC"]==null){
            $this->conn->executeQuery(self::DELETE_TABEPRECGER,$params);
        }
        $this->conn->executeQuery(self::DELETE_TABEVEND,$params);
        $this->conn->executeQuery(self::DELETE_ITEMPRECO,$params);
        $this->conn->executeQuery(self::DELETE_ITEMPRECODIA,$params);
    }
    
    public function updatePrecoItem($params){
        $this->entityManager->getConnection()->beginTransaction();
        try{
            $result = $this->conn->executeQuery(self::UPDATE_ITEMPRECO,$params);
            $this->entityManager->getConnection()->commit();
        }catch(Exception $e){
            $this->entityManager->getConnection()->rollBack();
            throw $e->getMessage;
        }
    }
    
    public function updatePrecoItemInline($NRORG,$CDTABEPREC,$DTINIVGPREC,$CDPRODUTO,$VRPRECITEM,$VRCUSTITEM,$VRPRESUGITEM, $VRPRECITEMCL, $IDPRODPROMOC, $HRINIVENPROD, $HRFIMVENPROD){
        $params = array(
            ':NRORG'        =>  $NRORG,
            ':CDTABEPREC'   =>  $CDTABEPREC,
            ':DTINIVGPREC'  =>  $DTINIVGPREC,
            ':CDPRODUTO'    =>  $CDPRODUTO,
            ':VRPRECITEM'   =>  $VRPRECITEM,
            ':VRCUSTITEM'   =>  $VRCUSTITEM,
            ':VRPRESUGITEM' =>  $VRPRESUGITEM,
            ':VRPRECITEMCL' =>  $VRPRECITEMCL,
            ':IDPRODPROMOC' =>  $IDPRODPROMOC,
            ':HRINIVENPROD' =>  $HRINIVENPROD,
            ':HRFIMVENPROD' =>  $HRFIMVENPROD
        );
        
        
        $this->conn->executeQuery(self::UPDATE_ITEMPRECO_INLINE,$params);
        
    }
    
    public function prodExistInITEMPRECO($produto){
        $params = array(
            ':NRORG'        =>  $produto['NRORG'],
            ':CDTABEPREC'   =>  $produto['CDTABEPREC'],
            ':DTINIVGPREC'  =>  $produto['DTINIVGPREC'],
            ':CDPRODUTO'    =>  $produto['CDPRODUTO']
        );
        $preco = $this->conn->fetchAssoc(self::FIND_PROD,$produto);
        return !$preco;
    }
    
    public function getInsertValidVigenciaDate($CDTABEPREC){
        $params = array(
            ':CDTABEPREC'   =>  $CDTABEPREC     
        );
        
        return $this->conn->fetchAll(self::GET_VALID_INSERT_VIGDATE,$params);
    }
    
       
        
    public function updatePrecoDiferenciado($CDTABEPREC,$DTINIVGPREC,$CDPRODUTO,$CDPRPAITABPR,$NRDIASEMANPR,$HRINIPRECDIA,$HRFINPRECDIA,$VRPRECODIA,$IDPERVALORPR,$IDDESCACREPR,$DTINIVALPREC,$DTFINVALPREC,$CDTIPOCONSPD,$IDVISUACUPOM,$NMTIPOCONS,$NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU,$VRPRECODIF){
        $params = array(
            ':CDTABEPREC'    =>  $CDTABEPREC,
            ':DTINIVGPREC'   =>  $DTINIVGPREC,
            ':CDPRODUTO'     =>  $CDPRODUTO,
            ':CDPRPAITABPR'  =>  $CDPRPAITABPR,
            ':NRDIASEMANPR'  =>  $NRDIASEMANPR,
            ':HRINIPRECDIA'  =>  $HRINIPRECDIA,
            ':HRFINPRECDIA'  =>  $HRFINPRECDIA,
            ':VRPRECODIA'    =>  $VRPRECODIA,
            ':IDPERVALORPR'  =>  $IDPERVALORPR,
            ':IDDESCACREPR'  =>  $IDDESCACREPR,
            ':DTINIVALPREC'  =>  $DTINIVALPREC,
            ':DTFINVALPREC'  =>  $DTFINVALPREC,
            ':CDTIPOCONSPD'  =>  $CDTIPOCONSPD,
            ':IDVISUACUPOM'  =>  $IDVISUACUPOM,
            ':NMTIPOCONS'    =>  $NMTIPOCONS,
            ':NRORG'         =>  $NRORG,
            ':CDOPERULTATU'  =>  $CDOPERULTATU,
            ':DTULTATU'      =>  $DTULTATU,
            ':NRORGULTATU'   =>  $NRORGULTATU,
            ':VRPRECODIF'    =>  $VRPRECODIF
        );
        
        return $this->conn->executeQuery(self::UPDATE_PRECODIFERENCIADO,$params);
    }
    
    
    
    public function verificaPrecoDifConsumidor($row){
        $return = true;
        $params = array(
            ':CDTABEPREC'    =>  $row['CDTABEPREC'],
            ':DTINIVGPREC'   =>  $row['DTINIVGPREC'],
            ':CDPRODUTO'     =>  $row['CDPRODUTO'],
            ':CDPRPAITABPR'  =>  $row['CDPRPAITABPR'],
            ':NRDIASEMANPR'  =>  $row['NRDIASEMANPR'],
            ':HRINIPRECDIA'  =>  $row['HRINIPRECDIA'],
            ':DTINIVALPREC'  =>  $row['DTINIVALPREC'],
            ':CDTIPOCONSPD'  =>  $row['CDTIPOCONSPD'],
            ':NRORG'         =>  $row['NRORG']
        );
        $dados = $this->conn->fetchAssoc(self::SELECT_PRECODIFERENCIADO,$params);
        if(!empty($dados)){
            if($dados['TOT'] > 0){
                $return = false;
            }else{
                $return = true;
            }
        }else{
            $return = true;
        }
        return $return;
    }
    
    public function getUpdateValidVigenciaDate($CDTABEPREC,$DTINIVGPREC,$DTFINVGPREC){
        $params = array(
            ':CDTABEPREC'   =>  $CDTABEPREC,
            ':DTINIVGPREC'  =>  $DTINIVGPREC,
            ':DTFINVGPREC'  =>  $DTFINVGPREC
        );
        return $this->conn->fetchAll(self::GET_VALID_UPDATE_VIGDATE,$params);
    }
    
    public function updatePrecoItemInlinePrecoDiferenciado($params){
        $result = $this->conn->executeQuery(self::UPDATE_ITEMPRECO_INLINE_PRECODIFERENCIADO,$params);
    }
    
    public function updItemPrecoAtuPrec($params) {
        $result = $this->conn->executeQuery(self::updItemPrecoAtuPrec,$params);
        return $result;
    }
    
    public function adqParamVend($params) {
        $result = $this->conn->fetchAll(self::adqParamVend,$params);
        return $result;
    }
    
    public function adqModProduto($params) {
        $result = $this->conn->fetchAll(self::adqModProduto,$params);
        return $result;
    }
    
    public function adqPadraoLocal($params) {
        $result = $this->conn->fetchAll(self::adqPadraoLocal,$params);
        return $result;
    }
    
    public function adqAuxFilial($params) {
        $result = $this->conn->fetchAll(self::adqAuxFilial,$params);
        return $result;
    }
    
    public function adqItemPreco($params) {
        $result = $this->conn->fetchAll(self::adqItemPreco,$params);
        return $result;
    }
    

    
    public function setPrecoAutomatico($params) {
        $result = $this->conn->executeQuery(self::SET_PRECO_AUTOMATICO, $params);
        return $result;
    }
    
    public function deletePreco($row) {
        $params = array(
            ':NRORG'       => $row['NRORG'],
            ':CDTABEPREC'  => $row['CDTABEPREC'],
            ':CDPRODUTO'   => $row['CDPRODUTO'],
            ':DTINIVGPREC' => $row['DTINIVGPREC']
        );
        $this->conn->executeQuery(self::DELETE_PRECO, $params);
    }
    
    public function deletePrecosDiferenciados($row) {
        $params = array(
            ':NRORG'       => $row['NRORG'],
            ':CDTABEPREC'  => $row['CDTABEPREC'],
            ':CDPRODUTO'   => $row['CDPRODUTO'],
            ':DTINIVGPREC' => $row['DTINIVGPREC']
        );
        $this->conn->executeQuery(self::DELETE_PRECOS_DIFERENCIADOS, $params);
    }
        
    public function deletePrecosDiferenciadosDia($row) {
        $params = array(
            ':NRORG'       => $row['NRORG'],
            ':CDTABEPREC'  => $row['CDTABEPREC'],
            ':CDPRODUTO'   => $row['CDPRODUTO'],
            ':DTINIVGPREC' => $row['DTINIVGPREC'],
            ':NRDIASEMANPR' => $row['NRDIASEMANPR'],
            ':CDTIPOCONSPD' => $row['CDTIPOCONSPD']
        );
        $this->conn->executeQuery(self::DELETE_PRECOS_DIFERENCIADOS_DIA, $params);
    }
    
    public function unidadesNotIn($row){
     $params = array(
            ':NRORG'       => $row['NRORG'],
            ':CDTABEPREC'       => $row['CDTABEPREC']
        );
        $arrayRetorno = [];
        $unidades =  $this->conn->fetchAll(self::GET_UNIDADES_NOT_IN, $params);
        foreach($unidades as $un){
            array_push($arrayRetorno, $un['CDFILIAL']);
        }
        return $arrayRetorno;
        
    }
    
    public function findUnidadeDisp($row){
        $params = array(
            ':NRORG'        => $row['NRORG'],
            ':CDTABEPREC'   => $row['CDTABEPREC'],
            ':DTINIVGPREC'  => $row['DTINIVGPREC'],
            ':DTFINVGPREC'  => $row['DTFINVGPREC'],
            
        );
        return $this->conn->fetchAll(self::FIND_UNIDADES, $params);
    }
    
    public function deleteFilialTabelaPreco($row){
        $params = array(
            ':NRORG'       => $row['NRORG'],
            ':CDTABEPREC'       => $row['CDTABEPREC']
        );
        return $this->conn->executeQuery(self::DELETE_ALL_UNIDADES_TABPREC, $params);
    }
    
   
    
    public function getPRECOITEMDIA($dataExport){
        $data   = $dataExport['DATA'];
        $paramsQuery = array(
            'CDTABEPREC' => $data['CDTABEPRECDES'],
            'CDTABEPRECORI' => $data['CDTABEPRECORI'],
            'CDPRODUTO'  => implode('_', $data['CDPRODUTO']),
            'TCDPRODUTO' => $data['TCDPRODUTO'],
            'NRORG'      => $data['NRORG']
        );
        
        $CDPRODUTO = explode("_",$paramsQuery['CDPRODUTO']);
        $RETURN = [];
        foreach ($CDPRODUTO as $value) {
            $paramsQuery['CDPRODUTO'] = $value;
            if($data['KEEP_PRECO'] == 'S'){
                $result = $this->entityManager->getConnection()->fetchAll(self::FIND_ITEM_PRECODIA_KEEP_PRICE, $paramsQuery);
            } else {
                $result = $this->entityManager->getConnection()->fetchAll(self::FIND_ITEM_PRECODIA, $paramsQuery);
            }
            array_merge($RETURN, $result);
        }
        return $RETURN;
    }
    
    public function getPRECOITEM($dataExport){
        
        $data   = $dataExport['DATA'];
        $paramsQuery = array(
            'CDTABEPREC' => $data['CDTABEPRECDES'],
            'CDTABEPRECORI' => $data['CDTABEPRECORI'],
            'CDPRODUTO'  => implode('_', $data['CDPRODUTO']),
            'TCDPRODUTO' => $data['TCDPRODUTO'],
            'NRORG'      => $data['NRORG']
        );
        
        $CDPRODUTO = explode("_",$paramsQuery['CDPRODUTO']);
        $RETURN = [];
        foreach ($CDPRODUTO as $value) {
            $paramsQuery['CDPRODUTO'] = $value;
            $result = $this->entityManager->getConnection()->fetchAll(self::FIND_ITEM_PRECO, $paramsQuery);
            array_merge($RETURN, $result);
        }
        return $RETURN;
    }
    
    public function exportPriceChart($data){
        
        $paramsQuery = Array();
        $tabeVend    = Array();
        try {
            if ($data['TCDPRODUTO'] == self::T_PRODUCT){
                // exportar todos os produtos, clona a tabela de preço origem com suas vigências
                self::formatIncTProductT($paramsQuery, $data);
                if(array_key_exists('DTVIGTAB', $data) && $data['DTVIGTAB']){
                    self::formatParamsQueryToVigDest($paramsQuery, $data);
                    $this->entityManager->getConnection()->executeQuery(self::INSERT_TABEVENDFROMSELECTWITHVIG, $paramsQuery);
                } else {
                    $this->entityManager->getConnection()->executeQuery(self::INSERT_TABEVENDFROMSELECT, $paramsQuery);
                }
                if(array_key_exists('DTVIGTAB', $data) && $data['DTVIGTAB']){
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECOFROMSELECTWITHVIG, $paramsQuery);
                    } else {
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECOFROMSELECT, $paramsQuery);
                    }
                
                if($data['EXPORT_PRECODIA'] == 'S'){
                    if(array_key_exists('DTVIGTAB', $data) && $data['DTVIGTAB']){
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECODIAFROMSELECTWITHVIG, $paramsQuery);
                    } else {
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECODIAFROMSELECT, $paramsQuery);
                    }
                }
                
            }
            else {
                // exportar lista de produtos
                self::formatTabeVend($paramsQuery, $data);
                $tabeVend = $this->entityManager->getConnection()->fetchAll(self::GET_TABEVEND, $paramsQuery); 
                if (empty($tabeVend)){
                    // se não existir vigência na tabela de destino, as vigências são clonadas da tabela origem
                    self::formatIncTProductT($paramsQuery, $data);
                    if(array_key_exists('DTVIGTAB', $data) && $data['DTVIGTAB']){
                        self::formatParamsQueryToVigDest($paramsQuery, $data);
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_TABEVENDFROMSELECTWITHVIG, $paramsQuery);
                    } else {
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_TABEVENDFROMSELECT, $paramsQuery);
                    }
                    // insere na ITEMPRECO e ITEMPRECODIA a lista de produtos nas tabelas de preço de acordo com os registros da tabela origem
                    self::formatIncTProducL($paramsQuery, $data);
                    $CDPRODUTO = explode("_",$paramsQuery['CDPRODUTO']);
                    foreach ($CDPRODUTO as $value) {
                        $paramsQuery['CDPRODUTO'] = $value;
                        if(array_key_exists('DTVIGTAB', $data) && $data['DTVIGTAB']){
                            self::formatParamsQueryToVigDest($paramsQuery, $data);
                            $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECOFROMSELECTLISTPRODUCTWITHVIG, $paramsQuery);
                        } else {
                            $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECOFROMSELECTLISTPRODUCT, $paramsQuery);
                        }
                        if($data['EXPORT_PRECODIA'] == 'S'){
                            if(array_key_exists('DTVIGTAB', $data) && $data['DTVIGTAB']){
                                self::formatParamsQueryToVigDest($paramsQuery, $data);
                                $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECODIAFROMSELECTLISTPRODUCTWITHVIG, $paramsQuery);
                            } else {
                                $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECODIAFROMSELECTLISTPRODUCT, $paramsQuery);
                            }
                        }    
                    }
                }
                else {
                    // se existir insere os produtos em todas as vigências da tabela de destino
                    foreach ($tabeVend as $validity) {
                        self::formatIncLProducL($paramsQuery, $data, $validity);
                        
                        $verifyInsert = $this->entityManager->getConnection()->fetchAll(self::VERIFICA_VALIDINSERT, $paramsQuery);
                        
                        if(!empty($verifyInsert)){
                            $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECOWITHVALIDITY, $paramsQuery);
                            if($data['EXPORT_PRECODIA'] == 'S')
                                $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECODIAWITHVALIDITY, $paramsQuery);
                        }else{
                            return self::WITHOUTVIG_PC;
                        }
                }
            }
            }
        } catch (Exception $e) {
            throw $e;            
        }
    }
    
    public function exportPriceChartControl($dataExport){
    // seleciona qual tipo de exportação será realizada
    
        $status = null;
        
        $data   = $dataExport['DATA'];
        try {
            self::controlTransaction('begin');            
        } catch (Exception $e) {
            return self::ERROR_PC;
        }
        
        $params = array(
            ':NRORG'         => $data['NRORG'],
            ':CDTABEPRECDES' => $data['CDTABEPRECDES'],
            ':CDTABEPRECORI' => $data['KEEP_PRECO'] == 'S' ?  $data['CDTABEPRECORI'] : $data['CDTABEPRECDES'],
            );
        if(count($data['CDPRODUTO']) == 0){
            $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEM_PRECO, $params);
            $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEM_PRECODIA, $params);
        } else if(count($data['CDPRODUTO']) > 0 &&  !!$data['CDTABEPRECDES']){
            foreach($data['CDPRODUTO'] as $cdproduto ){
                $params[':CDPRODUTO'] = $cdproduto;
                $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEM_PRECO_PROD, $params);
                $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEM_PRECODIA_PROD, $params);
            }
        }
        else {
            $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEM_PRECO, $params);
            $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEM_PRECODIA, $params);
        }
        switch ($dataExport['TYPE']) {
            case self::PRICECHART:
                $status = self::exportPriceChartSelect($data);
                break;

            case self::NEWPRICECHART:
                $status = self::exportNewPriceChart($data);
                break;
        }
        return $status;
    }
    
    public function exportNewPriceChart($data){
        
        // cria nova tabela de preço para filial de destino
        $paramsQuery = Array();
        $tabeprec    = Array();
        
        try {
            // verica se tabela de preço já existe para filial destino
            self::formatTabePrec($paramsQuery, $data);
            $tabeprec = $this->entityManager->getConnection()->fetchAll(self::GET_TABEPRECFROMCDTABEPREC, $paramsQuery);
            if (empty($tabeprec)){
                // Devido a filial nao existir nenhum valor filho deveria existir, os deletes abaixo limpam as tabelas por garantia.
                $this->entityManager->getConnection()->executeQuery(self::CLEAR_TO_INSERT_ITEMPRECODIA, $paramsQuery);
                $this->entityManager->getConnection()->executeQuery(self::CLEAR_TO_INSERT_ITEMPRECO, $paramsQuery);
                $this->entityManager->getConnection()->executeQuery(self::CLEAR_TO_INSERT_TABEVEND, $paramsQuery);
                $this->entityManager->getConnection()->executeQuery(self::CLEAR_TO_INSERT_TABEPRECGER, $paramsQuery);
                
                $this->entityManager->getConnection()->executeQuery(self::INSERT_TABEPRECEXP, $paramsQuery);
                $data['CDTABEPRECDES'] = $data['CDTABEPRECNEW'];
                // continua exportação
                self::exportPriceChart($data);

                self::controlTransaction('commit');
                return self::SUCCESS_PC;                
            }
            else {
                self::controlTransaction('rollback');
                return self::ALREADY;                
            }
        } catch (Exception $e) {
            self::controlTransaction('rollback');
            return self::ERROR_PC;
        }
    }
    public function ExcluirPrecoDif($dataExport){
        $data   = $dataExport['DATA'];
        self::formatDesProduct($paramsQuery, $data);
            $CDPRODUTO = explode("_",$paramsQuery['CDPRODUTO']);
            foreach ($CDPRODUTO as $value) {
                $paramsQuery['CDPRODUTO'] = $value;
                if($data['DELETE_PRECODIA'] == 'S')
                    $this->entityManager->getConnection()->executeQuery(self::DELETE_PRODUCTITEMPRECODIA, $paramsQuery);
            }
    }
    
    public function exportPriceChartSelect($data){
        
        // modifica tabela de preço de destino para exportação
        $paramsQuery = Array();
        try {
            self::formatDesProduct($paramsQuery, $data);
            $CDPRODUTO = explode("_",$paramsQuery['CDPRODUTO']);
            foreach ($CDPRODUTO as $value) {
                $paramsQuery['CDPRODUTO'] = $value;
                if($data['DELETE_PRECODIA'] == 'P')
                    $this->entityManager->getConnection()->executeQuery(self::DELETE_PRODUCTITEMPRECODIA, $paramsQuery);
            }
            $existProdutoItemPreco = $this->entityManager->getConnection()->fetchAll(self::EXIST_PRODUTO_ITEMPRECO);
            $existProdutoItemPrecoDia = $this->entityManager->getConnection()->fetchAll(self::EXIST_PRODUTO_ITEMPRECODIA);
            // caso a exportação seja para todos os produtos, exclui as vigência na TABEVEND
            if ($data['TCDPRODUTO'] == self::T_PRODUCT){
                self::formatTabeVend($paramsQuery, $data);
                $this->entityManager->getConnection()->executeQuery(self::DELETE_TABEVENDWITHCDTABEPREC, $paramsQuery);  
            }elseif($existProdutoItemPreco[0]['NUM'] == 0 && $existProdutoItemPrecoDia[0]['NUM'] == 0){
                self::formatTabeVend($paramsQuery, $data);
                $this->entityManager->getConnection()->executeQuery(self::DELETE_TABEVENDWITHCDTABEPREC, $paramsQuery);
            }
            // continua exportação
            if((self::exportPriceChart($data)) == self::WITHOUTVIG_PC){
                self::controlTransaction('rollback');
                return self::WITHOUTVIG_PC;
            }else{
                self::controlTransaction('commit');
                return self::SUCCESS_PC;
            }
        } catch (Exception $e) {
            self::controlTransaction('rollback');
            return self::ERROR_PC;
        }
    }
    
    public function setPRECOITEMDIA($backupPrice){
        $i = 0;
        foreach($backupPrice as $data){
            $params = array(
                'CDTABEPREC' => $data['CDTABEPREC'],
                'DTINIVGPREC' => $data['DTINIVGPREC'],
                'CDPRODUTO' => $data['CDPRODUTO'],
                'CDPRPAITABPR' => $data['CDPRPAITABPR'],
                'NRDIASEMANPR' => $data['NRDIASEMANPR'],
                'HRINIPRECDIA' => $data['HRINIPRECDIA'],
                'HRFINPRECDIA' => $data['HRFINPRECDIA'],
                'VRPRECODIA' => $data['VRPRECODIA'],
                'IDPERVALORPR' => $data['IDPERVALORPR'],
                'IDDESCACREPR' => $data['IDDESCACREPR'],
                'DTINIVALPREC' => $data['DTINIVALPREC'],
                'DTFINVALPREC' => $data['DTFINVALPREC'],
                'DTULTATUITPD' => $data['DTULTATUITPD'],
                'CDTIPOCONSPD' => $data['CDTIPOCONSPD'],
                'IDVISUACUPOM' => $data['IDVISUACUPOM'],
                'NRORG' => $data['NRORG'],
                'DTINCLUSAO' => $data['DTINCLUSAO'],
                'NRORGINCLUSAO' => $data['NRORGINCLUSAO'],
                'CDOPERINCLUSAO' => $data['CDOPERINCLUSAO'],
                'NRORGULTATU' => $data['NRORGULTATU'],
                'CDOPERULTATU' => $data['CDOPERULTATU'],
                'IDATIVO' => $data['IDATIVO'],
                'CALCDESCONTOVRUNITARIO' => $data['CALCDESCONTOVRUNITARIO'],
                'NRTIPOPRECO' => $data['NRTIPOPRECO'],
                'VRPRECODIF' => $data['VRPRECODIF']
            );
                $this->entityManager->getConnection()->executeQuery(self::SET_ITEM_PRECODIA, $params);
         
            
            $i++;
        }
        return $i;
    }
    
    private function checkItemPrecoDiaExists($params){
        return $this->entityManager->getConnection()->fetchAll(self::GET_ITEM_PRECODIA, $params);
    }
    
    public function setPRECOITEM($backupPrice){
        
        foreach($backupPrice as $data){
            $params = array(
                'CDTABEPREC'     => $data['CDTABEPREC'],
                'DTINIVGPREC'    => $data['DTINIVGPREC'],
                'CDPRODUTO'      => $data['CDPRODUTO'],
                'CDPRPAITABPR'   => $data['CDPRPAITABPR'],
                'VRPRECITEM'     => $data['VRPRECITEM'],
                'VRPRECITEMCL'   => $data['VRPRECITEMCL'],
                'IDPRECVARIA'    => $data['IDPRECVARIA'],
                'VRPRESUGITEM'   => $data['VRPRESUGITEM'],
                'VRCUSTITEM'     => $data['VRCUSTITEM'],
                'VRMKUPITEM'     => $data['VRMKUPITEM'],
                'IDPRODPROMOC'   => $data['IDPRODPROMOC'],
                'NRORG'          => $data['NRORG'],
                'DTINCLUSAO'     => $data['DTINCLUSAO'],
                'NRORGINCLUSAO'  => $data['NRORGINCLUSAO'],
                'CDOPERINCLUSAO' => $data['CDOPERINCLUSAO'],
                'NRORGULTATU'    => $data['NRORGULTATU'],
                'CDOPERULTATU'   => $data['CDOPERULTATU'],
                'IDATIVO'        => $data['IDATIVO'],
                'HRINIVENPROD'   => $data['HRINIVENPROD'],
                'HRFIMVENPROD'   => $data['HRFIMVENPROD']
            );
            $this->entityManager->getConnection()->executeQuery(self::SET_ITEM_PRECO, $params);
        }
    }
    
    public function formatTabePrec(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDTABEPREC' => $data['CDTABEPRECNEW'],
            'NMTABEPREC' => $data['NMTABEPRECNEW'],
            'NRORG'      => $data['NRORG']
        );
    }
    
    public function formatIncTProductT(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDTABEPRECDES' => $data['CDTABEPRECDES'],
            'CDTABEPRECORI' => $data['CDTABEPRECORI'],            
            'NRORG'         => $data['NRORG']
        );
    }
    
    public function formatDesProduct(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDTABEPREC' => $data['CDTABEPRECDES'],
            'CDPRODUTO'  => implode('_', $data['CDPRODUTO']),
            'TCDPRODUTO' => $data['TCDPRODUTO'],
            'NRORG'      => $data['NRORG']
        );
    }
    
    private function formatParamsQueryToVigDest(&$paramsQuery, $data){
        $paramsQuery[':DTVGPROD']    = $data['DTINIVGPREC'];
        $paramsQuery[':DTINIVGPREC'] = $data['DTVIGTAB']['start'];
        $paramsQuery[':DTFINVGPREC'] = $data['DTVIGTAB']['end'];
        $paramsQuery[':NRORG']       = $data['NRORG'];
    }

    
    public function formatTabeVend(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDTABEPREC' => $data['CDTABEPRECDES'],
            'NRORG'      => $data['NRORG']
        );
    }
    
    
    public function formatIncTProducL(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDTABEPRECDES' => $data['CDTABEPRECDES'],
            'CDTABEPRECORI' => $data['CDTABEPRECORI'],
            'CDPRODUTO'     => implode('_', $data['CDPRODUTO']),            
            'NRORG'         => $data['NRORG']
        );
    }
    
    public function formatIncLProducL(&$paramsQuery, $data, $validity){
        $paramsQuery = array(
            'CDTABEPRECDES' => $data['CDTABEPRECDES'],
            'DTINIVGPREC'   => $validity['DTINIVGPREC'],
            'CDTABEPRECORI' => $data['CDTABEPRECORI'],
            'CDPRODUTO'     => implode('_', $data['CDPRODUTO']),            
            'NRORG'         => $data['NRORG']
        );
    }
    
    const GET_CDPROD = "
        SELECT CDPRODUTO FROM PRODUTO
            WHERE CDARVPROD = :CDARVPROD
    ";
    
    const GET_TABEPRECFROMCDTABEPREC = "
		SELECT * 
		FROM TABEPRECGER
		WHERE 
			(CDTABEPREC = :CDTABEPREC) AND
			(NRORG 	   = :NRORG)				 
	";
	
	const INSERT_TABEPRECEXP = "
		INSERT INTO TABEPRECGER
		    ( CDTABEPREC, NMTABEPREC, NRORG)
		VALUES
		 	( :CDTABEPREC, :NMTABEPREC, :NRORG)
	";
    
    	const FIND_ITEM_PRECO = "
    SELECT DISTINCT *
        FROM ITEMPRECOGER 
       WHERE
           (CDTABEPREC  = :CDTABEPREC) AND
           ((CDPRODUTO = :CDPRODUTO) OR (:TCDPRODUTO = 'T')) AND
           (NRORG = :NRORG) AND
           CDPRODUTO NOT IN (SELECT CDPRODUTO FROM ITEMPRECOGER WHERE CDTABEPREC = :CDTABEPRECORI)
    	";
    
    	const FIND_ITEM_PRECODIA = "
    SELECT DISTINCT ITD.*
        FROM ITEMPRECODIAGER ITD
        JOIN ITEMPRECOGER IT ON
        IT.CDPRODUTO = ITD.CDPRODUTO
       WHERE
           (ITD.CDTABEPREC  = :CDTABEPREC) AND
           (IT.CDTABEPREC  = :CDTABEPRECORI) AND
           ((ITD.CDPRODUTO = :CDPRODUTO) OR (:TCDPRODUTO = 'T')) AND
           (ITD.NRORG = :NRORG)
    	";
    
    const FIND_ITEM_PRECODIA_KEEP_PRICE = "
                SELECT DISTINCT ITD.*
        FROM ITEMPRECODIAGER ITD
       WHERE
           (ITD.CDTABEPREC  = :CDTABEPREC) AND
           ((ITD.CDPRODUTO = :CDPRODUTO) OR (:TCDPRODUTO = 'T')) AND
           (ITD.NRORG = :NRORG)
           AND ITD.CDPRODUTO||ITD.NRDIASEMANPR NOT IN (SELECT CDPRODUTO||NRDIASEMANPR FROM ITEMPRECODIAGER 
           WHERE CDTABEPREC  = :CDTABEPRECORI)
    	";
    
    const DELETE_ITEM_PRECO = "
	     DELETE FROM ITEMPRECOGER
	        WHERE 
	            CDTABEPREC   = :CDTABEPRECDES AND
	            NRORG       = :NRORG 
	            
	            
	";
	
	 const DELETE_ITEM_PRECODIA = "
	     DELETE FROM ITEMPRECODIAGER
	        WHERE 
	            CDTABEPREC   = :CDTABEPRECDES AND
	            NRORG       = :NRORG AND
	            CDPRODUTO IN (SELECT CDPRODUTO FROM ITEMPRECOGER 
	                            WHERE 
                        	            CDTABEPREC   = :CDTABEPRECORI AND
                        	            NRORG       = :NRORG)
	            
	";
	
	    const DELETE_ITEMDIA_PRECO = "
	     DELETE FROM ITEMPRECODIAGER
	        WHERE 
	            CDTABEPREC   = :CDTABEPRECDES AND
	            NRORG       = :NRORG AND
	            CDPRODUTO IN (SELECT CDPRODUTO FROM ITEMPRECOGER 
	                            WHERE 
                        	            CDTABEPREC   = :CDTABEPRECORI AND
                        	            NRORG       = :NRORG)
	            
	";
	
	const DELETE_ITEM_PRECO_PROD = "
	     DELETE FROM ITEMPRECOGER
	        WHERE 
	            CDTABEPREC   = :CDTABEPRECDES AND
	            CDPRODUTO = :CDPRODUTO AND
	            NRORG       = :NRORG
	";
	
	const DELETE_ITEM_PRECODIA_PROD = "
	     DELETE FROM ITEMPRECODIAGER
	        WHERE 
	            CDTABEPREC   = :CDTABEPRECDES AND
	            CDPRODUTO = :CDPRODUTO AND
	            NRORG       = :NRORG
	";

	
    const FIND_UNIDADES = "
    SELECT CDFILIAL, NMFILIAL 
    FROM FILIAL 
    WHERE CDFILIAL NOT IN (
        SELECT DISTINCT CDFILIAL FROM 
        FILITABGER FT 
        JOIN TABEVENDGER TG
        ON FT.CDTABEPREC = TG.CDTABEPREC
        WHERE (:DTINIVGPREC >= DTINIVGPREC AND :DTINIVGPREC <= DTFINVGPREC) 
        OR (:DTFINVGPREC >= DTINIVGPREC AND :DTFINVGPREC <= DTFINVGPREC)
        OR (:DTINIVGPREC <= DTINIVGPREC AND :DTFINVGPREC >= DTFINVGPREC)
    )
    ORDER BY CDFILIAL
    ";
    
    const GET_UNIDADES_NOT_IN = "
    SELECT DISTINCT CDFILIAL FROM FILITABGER WHERE CDTABEPREC <> :CDTABEPREC";
    
    const GET_VIGENCIAS = "
    SELECT * FROM (
SELECT
    PR.IDATIVO,
    PR.CDTABEPREC,
    PR.CDTABEPREC
    || ' - '
    || PR.NMTABEPREC AS GROUPED_LABEL,
    PR.NMTABEPREC,
    T.DTINIVGPREC,
    T.DTINIVGPREC   AS OLD_DTINIVGPREC,
    T.DTFINVGPREC,
    T.DTFINVGPREC   AS OLD_DTFINVGPREC,
    T.IDSITVGPREC,
    PR.NRORG,
    ( MAX(PR.CDTABEPREC) OVER(
        PARTITION BY PR.NRORG
    ) + 1 ) AS NEXT_CD,
    CASE
        WHEN T.DTINIVGPREC IS NULL THEN
            'Sem Vigência'
        WHEN SYSDATE BETWEEN T.DTINIVGPREC AND ( T.DTFINVGPREC + 1 ) THEN
            'Ativa'
        ELSE
            'Inativa'
    END AS STATUS_VIGENCIA
FROM
    TABEPRECGER   PR
    LEFT JOIN TABEVENDGER T ON PR.CDTABEPREC = T.CDTABEPREC
    
ORDER BY
    PR.CDTABEPREC,
    T.DTFINVGPREC) 
    WHERE
      (UPPER( GROUPED_LABEL||DTINIVGPREC||DTFINVGPREC||STATUS_VIGENCIA) LIKE UPPER(:SEARCH) OR :SEARCH IS NULL)
    
    ";
    
    const GET_UNIDADES = "
        SELECT FT.CDFILIAL, F.NMFILIAL, FT.CDTABEPREC 
        FROM FILITABGER FT 
        JOIN FILIAL F
            ON F.CDFILIAL = FT.CDFILIAL
        WHERE FT.CDTABEPREC = :CDTABEPREC
              
        AND (UPPER(F.CDFILIAL||F.NMFILIAL) LIKE UPPER(:SEARCH) OR :SEARCH IS NULL)
        ORDER BY FT.CDFILIAL";
        
    const SAVE_UNIDADES = "
    INSERT INTO FILITABGER (CDFILIAL, CDTABEPREC, DTINCLUSAO, CDOPERINCLUSAO, CDOPERULTATU) 
    VALUES (:CDFILIAL, :CDTABEPREC, SYSDATE, :CDOPERADOR, :CDOPERADOR)";
    
    const REMOVE_UNIDADES = "
     DELETE FROM FILITABGER WHERE CDFILIAL = :CDFILIAL AND CDTABEPREC = :CDTABEPREC";
     
    const DELETE_ALL_UNIDADES_TABPREC = "
     DELETE FROM FILITABGER WHERE NRORG = :NRORG AND CDTABEPREC = :CDTABEPREC";
    
    const GET_UNIDADES_TABEPREC = "
    SELECT CDFILIAL FROM FILITABGER WHERE CDTABEPREC = :CDTABEPREC";
    
    const GET_PROD_TABPREC = "
 SELECT DISTINCT P.CDPRODUTO, P.CDARVPROD, P.NMPRODUTO, P.NRORG, P.CDNVPRODUTO, IT.CDTABEPREC, IT.VRPRECITEM, IT.VRPRECITEMCL, IT.HRINIVENPROD, IT.HRFIMVENPROD, IT.VRCUSTITEM, IT.VRMKUPITEM, IT.VRPRESUGITEM, IT.IDPRODPROMOC, IT.CDPRPAITABPR, IT.IDPRECVARIA,
IT.DTINIVGPREC, DECODE(ITD.CDPRODUTO, null, 0, 1)  AS PRECDIA
    FROM PRODUTO P
    LEFT JOIN ITEMPRECOGER IT
    ON P.CDPRODUTO = IT.CDPRODUTO
    AND IT.DTINIVGPREC = :DTINIVGPREC
        AND IT.CDTABEPREC = :CDTABEPREC
    LEFT JOIN (SELECT DISTINCT  CDPRODUTO, DTINIVGPREC, CDTABEPREC FROM ITEMPRECODIAGER) ITD
    ON P.CDPRODUTO = ITD.CDPRODUTO
    AND ITD.DTINIVGPREC = :DTINIVGPREC
        AND ITD.CDTABEPREC = :CDTABEPREC
    WHERE P.NRORG = :NRORG 
        AND P.CDNVPRODUTO = :CDNVPRODUTO 
        AND P.IDPRODATIVPR = 'S'
        AND (UPPER(CDARVPROD||NMPRODUTO||VRPRECITEM||VRPRESUGITEM||VRPRECITEMCL||VRCUSTITEM||HRINIVENPROD||HRFIMVENPROD) LIKE UPPER(:SEARCH) OR :SEARCH IS NULL)
        AND ((((INSTR(:CDPRODLIST, P.CDPRODUTO) > 0 ) OR (P.CDARVPROD BETWEEN :CDARVPRODI AND :CDARVPRODF ))) OR (P.CDARVPROD LIKE :PRODNIV) OR (:TCDPRODUTO = 'T'))
        ORDER BY P.CDARVPROD";
        
    const FIND_PROD = "
    SELECT CDPRODUTO FROM ITEMPRECOGER 
    WHERE CDTABEPREC = :CDTABEPREC 
      AND CDPRODUTO = :CDPRODUTO
      AND DTINIVGPREC = :DTINIVGPREC
      AND NRORG = :NRORG";
    
    const DELETE_PRECOS_DIFERENCIADOS = "
        DELETE FROM ITEMPRECODIAGER
        WHERE
            NRORG =             :NRORG
            AND   CDTABEPREC  = :CDTABEPREC
            AND   CDPRODUTO   = :CDPRODUTO
            AND   DTINIVGPREC = :DTINIVGPREC
    ";
    
        const DELETE_PRECOS_DIFERENCIADOS_DIA = "
        DELETE FROM ITEMPRECODIAGER
        WHERE
            NRORG =             :NRORG
            AND   CDTABEPREC  = :CDTABEPREC
            AND   CDPRODUTO   = :CDPRODUTO
            AND   DTINIVGPREC = :DTINIVGPREC
            AND  NRDIASEMANPR = :NRDIASEMANPR
            AND  CDTIPOCONSPD = :CDTIPOCONSPD
    ";
    
    
    
        const DELETE_PRECO = "
        DELETE FROM ITEMPRECOGER
        WHERE
            NRORG =             :NRORG
            AND   CDTABEPREC  = :CDTABEPREC
            AND   CDPRODUTO   = :CDPRODUTO
            AND   DTINIVGPREC = :DTINIVGPREC
    ";
    
    const GET_CDGRUPPROD = "
  	SELECT
     PV.CDGRPRODPDV,
     GP.CDGRUPPROD||' - '||GP.NMGRUPPROD AS GRUPOPROD
    FROM
       PARAVEND PV, GRUPPROD GP
    WHERE
       (PV.CDFILIAL    = :P_CDFILIAL  ) AND
       (PV.NRORG       = :P_NRORG) AND
       (PV.NRORG       = GP.NRORG) AND
       (PV.CDGRPRODPDV = GP.CDGRUPPROD)
	";
	
	const GET_NRCONFIG = "
    	SELECT NRCONFIG
	    	FROM
	    	(SELECT
	       		COUNT(*) AS NRCONFIG
	    	  FROM PRSUBGRPROD
		    WHERE
		       (CDFILISUBGR = :P_CDFILISUBGR) AND
		       (CDGRUPPROD  = :P_CDGRUPPROD ) AND
		       (NRORG       = :P_NRORG)
		   	)
    ";//CDFILIAL CDGRPRODPDV
    
    const GET_VIGENCIA_BYTABELAPRECO_BYFILIAL = "
    SELECT DTINIVGPREC, DTFINVGPREC, 
    'De ' || TO_CHAR(DTINIVGPREC, 'DD/MM/YYYY') || ' até ' || TO_CHAR(DTFINVGPREC, 'DD/MM/YYYY') DTVGPRECLABEL,
      CASE 
       WHEN DTINIVGPREC IS NULL 
        THEN 'Sem Vigência' 
       WHEN SYSDATE BETWEEN DTINIVGPREC AND DTFINVGPREC 
        THEN 'Ativa' 
       ELSE 'Inativa'  
      END AS STATUS_VIGENCIA
    FROM TABEVEND
    WHERE (CDFILIAL     =  :P_CDFILIAL)   AND
          (CDTABEPREC   =  :P_CDTABEPREC) AND
          (DTINIVGPREC  <> :P_DTINIVGPREC )
    ORDER BY DTINIVGPREC
  ";
  
  const CHECK_PRECO_VIGENCIA_EXISTS = "
    SELECT CDFILIAL
      FROM ITEMPRECOGER
      WHERE (CDFILIAL    = :P_CDFILIAL)   AND
            (CDTABEPREC  = :P_CDTABEPREC) AND
            (DTINIVGPREC = :P_DTINIVGPREC)
      UNION
      SELECT CDFILIAL
      FROM ITEMPRECOCLI
      WHERE (CDFILIAL    = :P_CDFILIAL)   AND
            (CDTABEPREC  = :P_CDTABEPREC) AND
            (DTINIVGPREC = :P_DTINIVGPREC)
      UNION
      SELECT CDFILIAL
      FROM ITEMPRECOCON
      WHERE (CDFILIAL    = :P_CDFILIAL)   AND
            (CDTABEPREC  = :P_CDTABEPREC) AND
            (DTINIVGPREC = :P_DTINIVGPREC)
  ";
  
  const DELETE_ITEM_VIGENCIADES_1 = "
    DELETE
      FROM ITEMPRECODIAGER
     WHERE (CDFILIAL    = :P_CDFILIAL   )
       AND (CDTABEPREC  = :P_CDTABEPREC )
       AND (DTINIVGPREC = :P_DTINIVGPREC)
  " ;
  
  const DELETE_ITEM_VIGENCIADES_2 = "
    DELETE
      FROM ITEMPRECOGER
      WHERE (CDFILIAL    = :P_CDFILIAL)   
        AND (CDTABEPREC  = :P_CDTABEPREC) 
        AND (DTINIVGPREC = :P_DTINIVGPREC)
  ";
  
  const INSERT_ITEM_VIGENCIADES_1 = "
    INSERT INTO ITEMPRECOGER
      (CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR,
       VRPRECITEM, VRPRECITEMCL)
      (SELECT CDFILIAL, CDTABEPREC, :P_DTINIVGDEST, CDPRODUTO, CDPRPAITABPR,
              VRPRECITEM, VRPRECITEMCL
       FROM ITEMPRECOGER
       WHERE (CDFILIAL    = :P_CDFILIAL)   AND
             (CDTABEPREC  = :P_CDTABEPREC) AND
             (DTINIVGPREC = :P_DTINIVGORIG))
  " ;
  
  const INSERT_ITEM_VIGENCIADES_2 = "
    INSERT INTO ITEMPRECODIAGER
     (CDFILIAL, CDTABEPREC, DTINIVGPREC, DTINIVALPREC, DTFINVALPREC, CDPRODUTO, CDPRPAITABPR,
      NRDIASEMANPR, HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD)
    SELECT
       CDFILIAL, CDTABEPREC, :P_DTINIVGDEST, :P_DTINIVGDEST, :P_DTFINVGDEST, CDPRODUTO, CDPRPAITABPR,
       NRDIASEMANPR, HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD
    FROM
       ITEMPRECODIAGER
    WHERE
       (CDFILIAL    = :P_CDFILIAL   ) AND
       (CDTABEPREC  = :P_CDTABEPREC ) AND
       (DTINIVGPREC = :P_DTINIVGORIG)
      ";
      
      const GET_CDSEGMER = "
		SELECT DISTINCT
		   FI.CDFILIAL  , FI.NMFILIAL, FI.CDSEGMER, FI.CDEMPRESA,
		   FI.CDINSCESTA, E.CDPAIS   , E.SGESTADO , E.CDMUNICIPIO,
		   SE.CDSEGMER||' - '||SE.DSSEGMER AS SEGMENTO,
		   PA.IDPRECDIFCOM
		FROM
		   FILIAL FI
       LEFT JOIN SEGMERCADO SE ON
        (FI.CDSEGMER = SE.CDSEGMER)AND
        (FI.NRORG    = SE.NRORG)
      LEFT JOIN PARAVEND PA ON
        (FI.CDFILIAL = PA.CDFILIAL) AND
        (FI.NRORG    = PA.NRORG)
      LEFT JOIN ENDEFILI E ON
        (FI.CDFILIAL = E.CDFILIAL) AND
        (FI.NRORG    = E.NRORG   )
		WHERE
		  (FI.CDFILIAL = :P_CDFILIAL) AND
      (FI.NRORG    = :P_NRORG   )		  
		ORDER BY
		   FI.CDFILIAL
	";
	
	const INSERT_TABEPREC = "
  	INSERT INTO TABEPRECGER
  		(CDFILIAL,CDTABEPREC,NMTABEPREC,IDATIVO,CDOPERULTATU,DTULTATU,
      NRORGULTATU,CDOPERINCLUSAO,DTINCLUSAO,NRORG,NRORGINCLUSAO)
    VALUES
      (:CDFILIAL,:CDTABEPREC,:NMTABEPREC,:IDATIVO,:CDOPERULTATU,:DTULTATU,
      :NRORGULTATU,:CDOPERINCLUSAO,:DTINCLUSAO,:NRORG,:NRORGINCLUSAO)
  ";
  
  const UPDATE_TABEPREC = "
      UPDATE TABEPRECGER 
        SET CDOPERULTATU = :CDOPERULTATU,
            DTULTATU = SYSDATE,
            NRORGULTATU = :NRORGULTATU,
            NMTABEPREC =:NMTABEPREC
      WHERE CDTABEPREC = :CDTABEPREC AND 
            NRORG = :NRORG";
  
  const GET_ITEMPRECO = "
  SELECT * FROM ITEMPRECOGER
  WHERE CDTABEPREC = :CDTABEPREC
  AND DTINIVGPREC = :DTINIVGPREC
  AND CDPRODUTO = :CDPRODUTO";
  
  const INSERT_ITEMPRECO = "
    INSERT INTO ITEMPRECOGER
      (CDTABEPREC,DTINIVGPREC,CDPRODUTO,VRPRECITEM,VRCUSTITEM,VRPRESUGITEM,
      IDPRECVARIA,VRPRECITEMCL,IDPRODPROMOC,CDPRPAITABPR,IDATIVO,CDOPERULTATU,DTULTATU,
      NRORGULTATU,CDOPERINCLUSAO,DTINCLUSAO,NRORG,NRORGINCLUSAO, HRFIMVENPROD, HRINIVENPROD)
    VALUES
      (:CDTABEPREC,:DTINIVGPREC,:CDPRODUTO,:VRPRECITEM,:VRCUSTITEM,:VRPRESUGITEM,
      :IDPRECVARIA,:VRPRECITEMCL,:IDPRODPROMOC,:CDPRPAITABPR,:IDATIVO,:CDOPERULTATU,SYSDATE,
      :NRORGULTATU,:CDOPERULTATU,SYSDATE,:NRORG,:NRORG, :HRFIMVENPROD, :HRINIVENPROD)
	";
	
	const INSERT_VIGENCIA = "
  INSERT INTO TABEVENDGER (CDTABEPREC,DTINIVGPREC,DTFINVGPREC,CDOPERINCLUSAO,DTINCLUSAO,NRORGINCLUSAO,NRORG,CDOPERULTATU,DTULTATU,NRORGULTATU) VALUES
  ( :CDTABEPREC, :DTINIVGPREC, :DTFINVGPREC, :CDOPERINCLUSAO, :DTINCLUSAO, :NRORGINCLUSAO, :NRORG, :CDOPERULTATU, :DTULTATU, :NRORGULTATU)
	";
	
	const UPDATE_VIGENCIA = "
      UPDATE TABEVENDGER 
        SET DTFINVGPREC = :DTFINVGPREC,
            CDOPERULTATU = :CDOPERULTATU,
            DTULTATU = :DTULTATU,
            NRORGULTATU = :NRORGULTATU
      WHERE DTINIVGPREC = :OLD_DTINIVGPREC AND
            DTFINVGPREC = :OLD_DTFINVGPREC AND
            CDTABEPREC = :CDTABEPREC AND 
            NRORG = :NRORG";
    
    const DELETE_TABEVEND = "
  	DELETE FROM TABEVENDGER
  	 WHERE  DTINIVGPREC	= :DTINIVGPREC
  	   AND CDTABEPREC	  = :CDTABEPREC
  	   AND NRORG	      = :NRORG
  ";
  const DELETE_TABEPRECGER = "
  	DELETE FROM TABEPRECGER
  	 WHERE CDTABEPREC	  = :CDTABEPREC
  	   AND NRORG	      = :NRORG
  ";
  
      const DELETE_ITEMPRECO = "
  	DELETE FROM ITEMPRECOGER
  	 WHERE  DTINIVGPREC	= :DTINIVGPREC
  	   AND CDTABEPREC	  = :CDTABEPREC
  	   AND NRORG	      = :NRORG
  ";
  
      const DELETE_ITEMPRECODIA = "
  	DELETE FROM ITEMPRECODIAGER
  	 WHERE  DTINIVGPREC	= :DTINIVGPREC
  	   AND CDTABEPREC	  = :CDTABEPREC
  	   AND NRORG	      = :NRORG
  ";
  
  const UPDATE_ITEMPRECO = "
    UPDATE ITEMPRECOGER SET
      VRPRECITEM   = :VRPRECITEM,
      VRCUSTITEM   = :VRCUSTITEM,
      VRPRESUGITEM = :VRPRESUGITEM,
      IDPRECVARIA  = :IDPRECVARIA,
      VRPRECITEMCL = :VRPRECITEMCL,
      IDPRODPROMOC = :IDPRODPROMOC,
      CDPRPAITABPR = :CDPRPAITABPR,
      HRINIVENPROD = :HRINIVENPROD,
      HRFIMVENPROD = :HRFIMVENPROD
    
    WHERE  CDPRODUTO    = :CDPRODUTO
      AND CDTABEPREC   = :CDTABEPREC 
      AND DTINIVGPREC  = :DTINIVGPREC
      AND NRORG        = :NRORG";
      
      const UPDATE_ITEMPRECO_INLINE = "
    UPDATE ITEMPRECOGER SET
      VRPRECITEM   = :VRPRECITEM,
      VRCUSTITEM   = :VRCUSTITEM,
      VRPRESUGITEM = :VRPRESUGITEM,
      VRPRECITEMCL = :VRPRECITEMCL,
      IDPRODPROMOC = :IDPRODPROMOC,
      HRINIVENPROD = :HRINIVENPROD,
      HRFIMVENPROD = :HRFIMVENPROD
    
    WHERE  CDPRODUTO    = :CDPRODUTO
      AND CDTABEPREC   = :CDTABEPREC 
      AND DTINIVGPREC  = :DTINIVGPREC
      AND NRORG        = :NRORG";
      
      const GET_VALID_INSERT_VIGDATE = "
  SELECT DTINIVGPREC AS INICIO,
         DTFINVGPREC AS FIM
  FROM TABEVENDGER
  
  WHERE  CDTABEPREC = :CDTABEPREC
    
  UNION ALL
    
  SELECT MIN(DTINIVGPREC) AS INICIO,
         MAX(DTFINVGPREC) AS FIM
    FROM TABEVENDGER
  WHERE  CDTABEPREC = :CDTABEPREC";
    
    const UPDATE_PRECODIFERENCIADO = "
  UPDATE ITEMPRECODIAGER 
    SET VRPRECODIA = :VRPRECODIA,
        DTFINVALPREC = :DTFINVALPREC,
        IDPERVALORPR = :IDPERVALORPR,
        IDDESCACREPR = :IDDESCACREPR,
        HRFINPRECDIA = :HRFINPRECDIA,
        IDVISUACUPOM = :IDVISUACUPOM,
        CDOPERULTATU = :CDOPERULTATU,
        DTULTATUITPD  = SYSDATE,
        VRPRECODIF = :VRPRECODIF,
        NRORGULTATU = :NRORGULTATU
        
    WHERE 
          CDTABEPREC    = :CDTABEPREC   AND
          DTINIVGPREC   = :DTINIVGPREC  AND
          CDPRODUTO     = :CDPRODUTO    AND
          CDPRPAITABPR  = :CDPRPAITABPR AND
          NRDIASEMANPR  = :NRDIASEMANPR AND
          HRINIPRECDIA  = :HRINIPRECDIA AND
          DTINIVALPREC  = :DTINIVALPREC AND
          CDTIPOCONSPD  = :CDTIPOCONSPD AND
          NRORG         = :NRORG
	";
	
    const SELECT_PRECODIFERENCIADO = "
  SELECT COUNT(*) AS TOT FROM ITEMPRECODIAGER 
    WHERE 
          CDTABEPREC    = :CDTABEPREC   AND
          DTINIVGPREC   = :DTINIVGPREC  AND
          CDPRODUTO     = :CDPRODUTO    AND
          CDPRPAITABPR  = :CDPRPAITABPR AND
          NRDIASEMANPR  = :NRDIASEMANPR AND
          HRINIPRECDIA  = :HRINIPRECDIA AND
          DTINIVALPREC  = :DTINIVALPREC AND
          CDTIPOCONSPD  = :CDTIPOCONSPD AND
          NRORG         = :NRORG
	";
	
	const GET_VALID_UPDATE_VIGDATE = "
    SELECT DTINIVGPREC AS INICIO,
           DTFINVGPREC AS FIM
      FROM TABEVENDGER
      WHERE  CDTABEPREC = :CDTABEPREC
        AND DTINIVGPREC <> :DTINIVGPREC
        AND DTFINVGPREC <> :DTFINVGPREC
    
    UNION ALL
    
    SELECT * FROM
      (SELECT MIN(DTINIVGPREC) AS INICIO,
              MAX(DTFINVGPREC) AS FIM
      FROM TABEVENDGER
      WHERE  CDTABEPREC = :CDTABEPREC)
    
    WHERE INICIO <> :DTINIVGPREC
          AND FIM <> :DTFINVGPREC
	";

  
  const UPDATE_ITEMPRECO_INLINE_PRECODIFERENCIADO = "
      UPDATE ITEMPRECODIAGER
      SET VRPRECODIA = :VRPRECODIA
      WHERE CDTABEPREC = :CDTABEPREC
        AND DTINIVGPREC = :DTINIVGPREC
        AND CDPRODUTO = :CDPRODUTO
        AND CDPRPAITABPR = :CDPRPAITABPR
        AND NRDIASEMANPR = :NRDIASEMANPR
        AND HRINIPRECDIA = :HRINIPRECDIA
        AND CDTIPOCONSPD = :CDTIPOCONSPD
        AND NRORG = :NRORG
  ";
  
  const updItemPrecoAtuPrec = "
    UPDATE ITEMPRECODER
    SET
       VRPRECITEM   = NVL(VRPRECITEM,0) + NVL(VRCUSTITEM,0) - (NVL(VRPRECITEM,0) + NVL(VRPRECITEMCL,0)),
       VRPRECMAXITE = NVL(VRPRECITEM,0) + NVL(VRCUSTITEM,0) - (NVL(VRPRECITEM,0) + NVL(VRPRECITEMCL,0))
    WHERE
       (CDFILIAL     = :CDFILIAL   ) AND
       (CDTABEPREC   = :CDTABEPREC ) AND
       (DTINIVGPREC  = :DTINIVGPREC) AND
       (VRCUSTITEM   <> 0          )
  ";
  
  const GET_INTERVALO_CAD_AUTOMATICO = "
    SELECT CDPRODUTO, CDARVPROD FROM PRODUTO WHERE NRORG = :NRORG AND (CDARVPROD BETWEEN :CDPRODUTOINI AND :CDPRODUTOFIN) AND CDNVPRODUTO = :CDNVPRODUTO
  ";
  
  const SET_PRECO_AUTOMATICO = "
    UPDATE ITEMPRECOGER SET VRPRECITEM = :VRPRECITEM WHERE CDTABEPREC = :CDTABEPREC AND CDFILIAL = :CDFILIAL AND NRORG = :NRORG AND CDPRODUTO = :CDPRODUTO AND DTINIVGPREC = :DTINIVGPREC
  ";
  
  	const INSERT_TABEVENDFROMSELECTWITHVIG = "
		INSERT INTO TABEVENDGER
		    ( CDTABEPREC, DTINIVGPREC, DTFINVGPREC, NRORG)
		VALUES
		    ( :CDTABEPRECDES, :DTINIVGPREC, :DTFINVGPREC, :NRORG)
	";
	
	const INSERT_TABEVENDFROMSELECT = "
		INSERT INTO TABEVENDGER
		    ( CDTABEPREC, DTINIVGPREC, DTFINVGPREC, NRORG)
		SELECT
		     :CDTABEPRECDES, DTINIVGPREC, DTFINVGPREC, NRORG
		FROM
		    TABEVENDGER
		WHERE
		    (CDTABEPREC = :CDTABEPRECORI) AND
		    (NRORG 		= :NRORG)
	";
	
	const SET_ITEM_PRECODIA = "
	INSERT INTO ITEMPRECODIAGER 
	        (
	             CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR, 
	            NRDIASEMANPR, HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, 
	            IDDESCACREPR, DTINIVALPREC, DTFINVALPREC, DTULTATUITPD, CDTIPOCONSPD,
	            IDVISUACUPOM, NRORG, DTINCLUSAO, NRORGINCLUSAO,
                CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, IDATIVO, CALCDESCONTOVRUNITARIO, 
                NRTIPOPRECO, VRPRECODIF
            )
            VALUES 
            (
                 :CDTABEPREC, :DTINIVGPREC, :CDPRODUTO, :CDPRPAITABPR,
                :NRDIASEMANPR, :HRINIPRECDIA, :HRFINPRECDIA, :VRPRECODIA, :IDPERVALORPR,
                :IDDESCACREPR, :DTINIVALPREC, :DTFINVALPREC, :DTULTATUITPD, :CDTIPOCONSPD,
                :IDVISUACUPOM, :NRORG, :DTINCLUSAO, :NRORGINCLUSAO,
                :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU, :IDATIVO, :CALCDESCONTOVRUNITARIO,
                :NRTIPOPRECO, :VRPRECODIF
            )";
    
    const GET_ITEM_PRECODIA = "
    SELECT * FROM ITEMPRECODIA 
        WHERE 
            CDTABEPREC  = :CDTABEPREC AND
            CDPRODUTO   = :CDPRODUTO AND
            NRDIASEMANPR = :NRDIASEMANPR ";
    
    const SET_ITEM_PRECO = "
	INSERT INTO ITEMPRECOGER 
	        (
	             CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR, VRPRECITEM, VRPRECITEMCL ,
	            IDPRECVARIA, VRPRESUGITEM, VRCUSTITEM, VRMKUPITEM, IDPRODPROMOC,
	             NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU,
	            IDATIVO, HRINIVENPROD, HRFIMVENPROD
            )
            VALUES 
            (
                 :CDTABEPREC, :DTINIVGPREC, :CDPRODUTO, :CDPRPAITABPR, :VRPRECITEM, :VRPRECITEMCL,
	            :IDPRECVARIA, :VRPRESUGITEM, :VRCUSTITEM, :VRMKUPITEM, :IDPRODPROMOC, 
	             :NRORG, :DTINCLUSAO, SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU,
	            :IDATIVO, :HRINIVENPROD, :HRFIMVENPROD
        )";
        
    const INSERT_ITEMPRECOFROMSELECT = "
		INSERT INTO ITEMPRECOGER
		    ( CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR,
		    VRPRECITEM, VRPRECITEMCL, IDPRECVARIA, NRORG, IDPRODPROMOC,VRPRESUGITEM,VRCUSTITEM,HRINIVENPROD,HRFIMVENPROD)
		SELECT
		     :CDTABEPRECDES, I.DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR,
		    NVL(I.VRPRECITEM, 0), NVL(I.VRPRECITEMCL,0), NVL(I.IDPRECVARIA,0), I.NRORG, I.IDPRODPROMOC, NVL(I.VRPRESUGITEM,0), NVL(I.VRCUSTITEM,0), I.HRINIVENPROD, I.HRFIMVENPROD
		FROM
		    ITEMPRECOGER I, PRODUTO R
	    WHERE
		    
		    (I.CDTABEPREC = :CDTABEPRECORI) AND
		    (I.NRORG 	  = :NRORG) 		AND
		    (R.CDPRODUTO  = I.CDPRODUTO)    AND
		    (R.NRORG 	  = I.NRORG)		AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S')
	";
	
	const INSERT_ITEMPRECOFROMSELECTWITHVIG = "
		INSERT INTO ITEMPRECOGER
		    ( CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR,
		    VRPRECITEM, VRPRECITEMCL, IDPRECVARIA, NRORG, IDPRODPROMOC, HRINIVENPROD, HRFIMVENPROD)
		SELECT
		     :CDTABEPRECDES, :DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR,
		    NVL(I.VRPRECITEM, 0), NVL(I.VRPRECITEMCL,0), NVL(I.IDPRECVARIA,0), I.NRORG, I.IDPRODPROMOC, I.HRINIVENPROD, I.HRFIMVENPROD
		FROM
		    ITEMPRECOGER I, PRODUTO R
	    WHERE
		   
		    (I.CDTABEPREC = :CDTABEPRECORI) AND
		    (I.DTINIVGPREC = :DTVGPROD)    AND
		    (I.NRORG 	  = :NRORG) 		AND
		    (R.CDPRODUTO  = I.CDPRODUTO)    AND
		    (R.NRORG 	  = I.NRORG)		AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S')
	";
	
	const INSERT_ITEMPRECODIAFROMSELECT = "
		INSERT INTO ITEMPRECODIAGER
		    ( CDTABEPREC, DTINIVGPREC, DTINIVALPREC, DTFINVALPREC, CDPRODUTO, CDPRPAITABPR, NRDIASEMANPR,
		    HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD, NRORG, IDVISUACUPOM)
		SELECT
		     :CDTABEPRECDES, I.DTINIVGPREC, I.DTINIVALPREC, I.DTFINVALPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.NRDIASEMANPR,
		    I.HRINIPRECDIA, I.HRFINPRECDIA, I.VRPRECODIA, I.IDPERVALORPR, I.IDDESCACREPR, I.CDTIPOCONSPD, I.NRORG, NVL(I.IDVISUACUPOM, 0)
		FROM
		    ITEMPRECODIAGER I,  PRODUTO R
	    WHERE
		    (I.CDTABEPREC = :CDTABEPRECORI) AND
		    (I.NRORG 	  = :NRORG)		    AND
		    (R.CDPRODUTO  = I.CDPRODUTO)	AND
		    (R.NRORG 	  = I.NRORG)		AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S')	
	";
	
	const INSERT_ITEMPRECODIAFROMSELECTWITHVIG = "
		INSERT INTO ITEMPRECODIAGER
		    ( CDTABEPREC, DTINIVGPREC, DTINIVALPREC, DTFINVALPREC, CDPRODUTO, CDPRPAITABPR, NRDIASEMANPR,
		    HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD, NRORG, IDVISUACUPOM)
		SELECT
		     :CDTABEPRECDES, :DTINIVGPREC, I.DTINIVALPREC, I.DTFINVALPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.NRDIASEMANPR,
		    I.HRINIPRECDIA, I.HRFINPRECDIA, I.VRPRECODIA, I.IDPERVALORPR, I.IDDESCACREPR, I.CDTIPOCONSPD, I.NRORG, NVL(I.IDVISUACUPOM, 0)
		FROM
		    ITEMPRECODIAGER I,  PRODUTO R
	    WHERE
		    (I.CDTABEPREC = :CDTABEPRECORI) AND
		    (I.DTINIVGPREC = :DTVGPROD)    AND
		    (I.NRORG 	  = :NRORG)		    AND
		    (R.CDPRODUTO  = I.CDPRODUTO)	AND
		    (R.NRORG 	  = I.NRORG)		AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S')	
	";
	
	const DELETE_PRODUCTITEMPRECODIA = "
		DELETE
    FROM ITEMPRECODIAGER
   WHERE
       (CDTABEPREC  = :CDTABEPREC) AND
       ((CDPRODUTO = :CDPRODUTO) OR (:TCDPRODUTO = 'T')) AND
       (NRORG = :NRORG)
	";
	
	const EXIST_PRODUTO_ITEMPRECODIA = "
      SELECT count(CDPRODUTO) AS NUM FROM ITEMPRECODIAGER
      ";
    const EXIST_PRODUTO_ITEMPRECO = "
      SELECT count(CDPRODUTO) AS NUM FROM ITEMPRECOGER
      ";
    const DELETE_ALLITEMPRECODIA = "
		DELETE
  			FROM ITEMPRECODIAGER
 		WHERE (INSTR(:CDFILIAL, CDFILIAL) <> 0)
 			AND NRORG = :NRORG
	";
	const DELETE_ALLITEMPRECO = "
		DELETE
  			FROM ITEMPRECOGER
 		WHERE (INSTR(:CDFILIAL, CDFILIAL) <> 0)
 			AND NRORG = :NRORG
	";
	
	const DELETE_TABEVENDWITHCDTABEPREC = "
		DELETE
		FROM TABEVENDGER
		WHERE 
		    (CDTABEPREC  = :CDTABEPREC) AND
		    (NRORG       = :NRORG)
	";
	
	const GET_TABEVEND = "
		SELECT *
		FROM TABEVENDGER
	    WHERE 
	        (CDTABEPREC = :CDTABEPREC) AND
	        (NRORG 		= :NRORG)
	";
	
	const INSERT_ITEMPRECOFROMSELECTLISTPRODUCT = "
		INSERT INTO ITEMPRECOGER
	  		( CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR,
	   		VRPRECITEM, VRPRECITEMCL, IDPRECVARIA, NRORG, IDPRODPROMOC, HRINIVENPROD, HRFIMVENPROD)
	 	SELECT
	   		 :CDTABEPRECDES, I.DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR,
	   		I.VRPRECITEM, I.VRPRECITEMCL, I.IDPRECVARIA, I.NRORG, I.IDPRODPROMOC, I.HRINIVENPROD, I.HRFIMVENPROD
	 	FROM ITEMPRECOGER I, PRODUTO R
	 	WHERE
		    (I.CDTABEPREC = :CDTABEPRECORI) 	  AND
		    (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0) AND
		    (I.NRORG 	  = :NRORG)		     	  AND
		    (R.CDPRODUTO  = I.CDPRODUTO)     	  AND
		    (R.NRORG 	  = I.NRORG)		 	  AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S') 
	";
	
	const INSERT_ITEMPRECOFROMSELECTLISTPRODUCTWITHVIG = "
		INSERT INTO ITEMPRECOGER
	  		( CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR,
	   		VRPRECITEM, VRPRECITEMCL, IDPRECVARIA, NRORG, IDPRODPROMOC, HRINIVENPROD, HRFIMVENPROD)
	 	SELECT
	   		 :CDTABEPRECDES, :DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR,
	   		I.VRPRECITEM, I.VRPRECITEMCL, I.IDPRECVARIA, I.NRORG, I.IDPRODPROMOC, I.HRINIVENPROD, I.HRFIMVENPROD
	 	FROM ITEMPRECOGER I, PRODUTO R
	 	WHERE
		    (I.CDTABEPREC = :CDTABEPRECORI) 	  AND
		    (I.DTINIVGPREC = :DTVGPROD)          AND
		    (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0) AND
		    (I.NRORG 	  = :NRORG)		     	  AND
		    (R.CDPRODUTO  = I.CDPRODUTO)     	  AND
		    (R.NRORG 	  = I.NRORG)		 	  AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S') 
	"; 
	
	const INSERT_ITEMPRECODIAFROMSELECTLISTPRODUCT = "
		INSERT INTO ITEMPRECODIAGER
	  		( CDTABEPREC, DTINIVGPREC, DTINIVALPREC, DTFINVALPREC, CDPRODUTO, CDPRPAITABPR, NRDIASEMANPR,
	   		HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD, IDVISUACUPOM)
	 	SELECT
	   		 :CDTABEPRECDES, I.DTINIVGPREC, I.DTINIVALPREC, I.DTFINVALPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.NRDIASEMANPR,
	   		I.HRINIPRECDIA, I.HRFINPRECDIA, I.VRPRECODIA, I.IDPERVALORPR, I.IDDESCACREPR, I.CDTIPOCONSPD, I.IDVISUACUPOM
	 	FROM ITEMPRECODIAGER I,  PRODUTO R
	 	WHERE
		    (I.CDTABEPREC = :CDTABEPRECORI) 	  AND
		    (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0) AND
		    (I.NRORG 	  = :NRORG)		     	  AND
		    (R.CDPRODUTO  = I.CDPRODUTO)     	  AND
		    (R.NRORG 	  = I.NRORG)		 	  AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S')
  	";
  	
  	const VERIFICA_VALIDINSERT = "
	SELECT 
	     :CDTABEPRECDES, :DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.VRPRECITEM, I.VRPRECITEMCL,
	    I.IDPRECVARIA, I.VRPRESUGITEM, I.VRCUSTITEM, I.VRMKUPITEM, I.IDPRODPROMOC, I.NRORG
	FROM ITEMPRECOGER I, TABEVENDGER T
	WHERE
	     (I.CDTABEPREC  = :CDTABEPRECORI)
	    AND (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0)
	    AND (I.NRORG       = :NRORG)
	    AND (I.CDTABEPREC  = T.CDTABEPREC)
	    AND (I.DTINIVGPREC = T.DTINIVGPREC)
	    AND (I.NRORG       = T.NRORG)
	   
	";
	
		const INSERT_ITEMPRECOWITHVALIDITY = "
	INSERT INTO ITEMPRECOGER
	    ( CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR, VRPRECITEM, VRPRECITEMCL, 
	    IDPRECVARIA, VRPRESUGITEM, VRCUSTITEM, VRMKUPITEM, IDPRODPROMOC, NRORG)	
	SELECT 
	     :CDTABEPRECDES, :DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.VRPRECITEM, I.VRPRECITEMCL, 
	    I.IDPRECVARIA, I.VRPRESUGITEM, I.VRCUSTITEM, I.VRMKUPITEM, I.IDPRODPROMOC, I.NRORG
	FROM ITEMPRECOGER I, TABEVENDGER T
	WHERE (I.CDTABEPREC  = :CDTABEPRECORI)
	    AND (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0)
	    AND (I.NRORG       = :NRORG)
	    AND (I.CDTABEPREC  = T.CDTABEPREC)
	    AND (I.DTINIVGPREC = T.DTINIVGPREC)
	    AND (I.NRORG       = T.NRORG)
  	";
  	
  	const INSERT_ITEMPRECODIAWITHVALIDITY = "
  	INSERT INTO ITEMPRECODIAGER
   		( CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR, NRDIASEMANPR, HRINIPRECDIA, CDTIPOCONSPD,
    	HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, DTINIVALPREC, DTFINVALPREC, IDVISUACUPOM, NRORG)
	SELECT 
		 :CDTABEPRECDES, :DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.NRDIASEMANPR, I.HRINIPRECDIA, I.CDTIPOCONSPD,
       	I.HRFINPRECDIA, I.VRPRECODIA, I.IDPERVALORPR, I.IDDESCACREPR, I.DTINIVALPREC, I.DTFINVALPREC, I.IDVISUACUPOM, I.NRORG
  	FROM ITEMPRECODIAGER I, TABEVENDGER T
  	WHERE
	     (I.CDTABEPREC  = :CDTABEPRECORI)
	    AND (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0)
	    AND (I.NRORG       = :NRORG)
	    AND (I.CDTABEPREC  = T.CDTABEPREC)
	    AND (I.DTINIVGPREC = T.DTINIVGPREC)
	    AND (I.NRORG       = T.NRORG)
  	";
  	
  	// Clear new Tabe Prec ger before insert
  	
    const CLEAR_TO_INSERT_TABEVEND = "
      	DELETE FROM TABEVENDGER
      	 WHERE CDTABEPREC	  = :CDTABEPREC
      	   AND NRORG	      = :NRORG
    ";
    const CLEAR_TO_INSERT_TABEPRECGER = "
  	  DELETE FROM TABEPRECGER
  	   WHERE CDTABEPREC	  = :CDTABEPREC
  	     AND NRORG	      = :NRORG
    ";
    
    const CLEAR_TO_INSERT_ITEMPRECO = "
  	  DELETE FROM ITEMPRECOGER
  	   WHERE CDTABEPREC	  = :CDTABEPREC
  	     AND NRORG	      = :NRORG
    ";
    
    const CLEAR_TO_INSERT_ITEMPRECODIA = "
  	  DELETE FROM ITEMPRECODIAGER
  	   WHERE CDTABEPREC	  = :CDTABEPREC
  	     AND NRORG	      = :NRORG
    ";
      
}  